#
# spec file for package selinux-policy
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# There are almost no SUSE specific modifications available in the policy, so we utilize the
# ones used by redhat and include also the SUSE specific ones (distro_suse_to_distro_redhat.patch)
%define distro redhat
%define ubac n
%define polyinstatiate n
%define monolithic n
%define BUILD_TARGETED 1
%define BUILD_MINIMUM 1
# At the moment we don't build the MLS policy. We didn't do any testing for this and have no
# confidence that it works. Feel free to branch the package and enable it, but be aware that
# you're on your own
%define BUILD_MLS 0

%define POLICYCOREUTILSVER %(rpm -q --qf %%{version} policycoreutils)
%define CHECKPOLICYVER %POLICYCOREUTILSVER

Summary:        SELinux policy configuration
License:        GPL-2.0-or-later
Group:          System/Management
Name:           selinux-policy
VCS: https://src.suse.de/SLFO-pool/selinux-policy?trackingbranch=main#a03204bbc950be4300dd9e7ebbc2cb0deefe2cd9f51ccdfc1cf13119e47786e4
Version:        20250627+git62.68c403828
Release:        160000.1.4
Source0:        %{name}-%{version}.tar.xz
Source1:        container.fc
Source2:        container.te
Source3:        container.if
Source4:        selinux-policy-rpmlintrc
Source5:        README.Update
Source6:        update.sh
Source7:        debug-build.sh

Source18:       modules-minimum.lst

Source60:       selinux-policy.conf

Source91:       Makefile.devel
Source95:       macros.selinux-policy

URL:            https://github.com/fedora-selinux/selinux-policy.git
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
BuildRequires:  checkpolicy
BuildRequires:  gawk
BuildRequires:  libxml2-tools
BuildRequires:  m4
BuildRequires:  policycoreutils
BuildRequires:  policycoreutils-devel
BuildRequires:  python3
BuildRequires:  python3-policycoreutils
# we need selinuxenabled
Requires(pre):  policycoreutils >= %{POLICYCOREUTILSVER}
Requires(pre):  pam-config
Requires(posttrans): pam-config
Requires(posttrans): selinux-tools
Requires(posttrans): /usr/bin/sha512sum
Recommends:     audit
Recommends:     selinux-tools
# for audit2allow
Recommends:     python3-policycoreutils
Recommends:     container-selinux
Recommends:     policycoreutils-python-utils
Recommends:     selinux-autorelabel

%define common_params DISTRO=%{distro} UBAC=%{ubac} DIRECT_INITRC=n MONOLITHIC=%{monolithic} MLS_CATS=1024 MCS_CATS=1024

%define makeCmds() \
%make_build %common_params UNK_PERMS=%3 NAME=%1 TYPE=%2 bare \
%make_build %common_params UNK_PERMS=%3 NAME=%1 TYPE=%2 conf \
install -p -m0644 ./dist/%1/booleans.conf ./policy/booleans.conf \
install -p -m0644 ./dist/%1/users ./policy/users \

%define makeModulesConf() \
install -p -m0644 ./dist/%1/modules.conf ./policy/modules.conf \

%define installCmds() \
%make_build %common_params UNK_PERMS=%3 NAME=%1 TYPE=%2 base.pp \
%make_build %common_params UNK_PERMS=%3 NAME=%1 TYPE=%2 validate modules \
make %common_params UNK_PERMS=%3 NAME=%1 TYPE=%2 DESTDIR=%{buildroot} install \
make %common_params UNK_PERMS=%3 NAME=%1 TYPE=%2 DESTDIR=%{buildroot} install-appconfig \
make %common_params UNK_PERMS=%3 NAME=%1 TYPE=%2 DESTDIR=%{buildroot} SEMODULE="%{_sbindir}/semodule -p %{buildroot} -X 100 " load \
%{__mkdir} -p %{buildroot}%{_sysconfdir}/selinux/%1/logins \
%{__mkdir} -p %{buildroot}%{_sharedstatedir}/selinux/%1/active/modules/{1,2,4}00 \
touch %{buildroot}%{_sysconfdir}/selinux/%1/contexts/files/file_contexts.subs \
install -m0644 ./config/file_contexts.subs_dist %{buildroot}%{_sysconfdir}/selinux/%1/contexts/files \
install -m0644 ./dist/%1/setrans.conf %{buildroot}%{_sysconfdir}/selinux/%1/setrans.conf \
install -m0644 ./dist/customizable_types %{buildroot}%{_sysconfdir}/selinux/%1/contexts/customizable_types \
touch %{buildroot}%{_sysconfdir}/selinux/%1/contexts/files/file_contexts.bin \
touch %{buildroot}%{_sysconfdir}/selinux/%1/contexts/files/file_contexts.local \
touch %{buildroot}%{_sysconfdir}/selinux/%1/contexts/files/file_contexts.local.bin \
install -p -m0644 ./dist/booleans.subs_dist %{buildroot}%{_sysconfdir}/selinux/%1 \
rm -f %{buildroot}%{_datadir}/selinux/%1/*pp*  \
%{_bindir}/sha512sum %{buildroot}%{_sysconfdir}/selinux/%1/policy/policy.* | cut -d' ' -f 1 > %{buildroot}%{_sysconfdir}/selinux/%1/.policy.sha512; \
rm -rf %{buildroot}%{_sysconfdir}/selinux/%1/contexts/netfilter_contexts  \
rm -rf %{buildroot}%{_sysconfdir}/selinux/%1/modules/active/policy.kern \
rm -f %{buildroot}%{_sharedstatedir}/selinux/%1/active/*.linked \
%nil

%define fileList() \
%defattr(-,root,root) \
%dir %{_sysconfdir}/selinux/%1 \
%config(noreplace) %{_sysconfdir}/selinux/%1/setrans.conf \
%config(noreplace) %verify(not md5 size mtime) %{_sysconfdir}/selinux/%1/seusers \
%dir %{_sysconfdir}/selinux/%1/logins \
%dir %{_sharedstatedir}/selinux/%1/active \
%verify(not md5 size mtime) %{_sharedstatedir}/selinux/%1/semanage.read.LOCK \
%verify(not md5 size mtime) %{_sharedstatedir}/selinux/%1/semanage.trans.LOCK \
%dir %attr(700,root,root) %{_sharedstatedir}/selinux/%1/active/modules \
%dir %{_sharedstatedir}/selinux/%1/active/modules/100 \
%dir %{_sharedstatedir}/selinux/%1/active/modules/200 \
%dir %{_sharedstatedir}/selinux/%1/active/modules/400 \
%verify(not md5 size mtime) %{_sharedstatedir}/selinux/%1/active/modules/100/base \
%dir %{_sysconfdir}/selinux/%1/policy/ \
%verify(not md5 size mtime) %{_sysconfdir}/selinux/%1/policy/policy.* \
%{_sysconfdir}/selinux/%1/.policy.sha512 \
%dir %{_sysconfdir}/selinux/%1/contexts \
%config %{_sysconfdir}/selinux/%1/contexts/customizable_types \
%config(noreplace) %{_sysconfdir}/selinux/%1/contexts/securetty_types \
%config(noreplace) %{_sysconfdir}/selinux/%1/contexts/dbus_contexts \
%config %{_sysconfdir}/selinux/%1/contexts/x_contexts \
%config %{_sysconfdir}/selinux/%1/contexts/default_contexts \
%config %{_sysconfdir}/selinux/%1/contexts/virtual_domain_context \
%config %{_sysconfdir}/selinux/%1/contexts/virtual_image_context \
%config %{_sysconfdir}/selinux/%1/contexts/lxc_contexts \
%config %{_sysconfdir}/selinux/%1/contexts/systemd_contexts \
%config %{_sysconfdir}/selinux/%1/contexts/sepgsql_contexts \
%config %{_sysconfdir}/selinux/%1/contexts/openssh_contexts \
%config %{_sysconfdir}/selinux/%1/contexts/snapperd_contexts \
%config(noreplace) %{_sysconfdir}/selinux/%1/contexts/default_type \
%config(noreplace) %{_sysconfdir}/selinux/%1/contexts/failsafe_context \
%config(noreplace) %{_sysconfdir}/selinux/%1/contexts/initrc_context \
%config(noreplace) %{_sysconfdir}/selinux/%1/contexts/removable_context \
%config(noreplace) %{_sysconfdir}/selinux/%1/contexts/userhelper_context \
%dir %{_sysconfdir}/selinux/%1/contexts/files \
%verify(not md5 size mtime) %{_sysconfdir}/selinux/%1/contexts/files/file_contexts \
%ghost %{_sysconfdir}/selinux/%1/contexts/files/file_contexts.bin \
%verify(not md5 size mtime) %{_sysconfdir}/selinux/%1/contexts/files/file_contexts.homedirs \
%ghost %{_sysconfdir}/selinux/%1/contexts/files/file_contexts.homedirs.bin \
%config(noreplace) %{_sysconfdir}/selinux/%1/contexts/files/file_contexts.local \
%ghost %{_sysconfdir}/selinux/%1/contexts/files/file_contexts.local.bin \
%config(noreplace) %{_sysconfdir}/selinux/%1/contexts/files/file_contexts.subs \
%{_sysconfdir}/selinux/%1/contexts/files/file_contexts.subs_dist \
%{_sysconfdir}/selinux/%1/booleans.subs_dist \
%config %{_sysconfdir}/selinux/%1/contexts/files/media \
%dir %{_sysconfdir}/selinux/%1/contexts/users \
%config(noreplace) %{_sysconfdir}/selinux/%1/contexts/users/root \
%config(noreplace) %{_sysconfdir}/selinux/%1/contexts/users/guest_u \
%config(noreplace) %{_sysconfdir}/selinux/%1/contexts/users/xguest_u \
%config(noreplace) %{_sysconfdir}/selinux/%1/contexts/users/user_u \
%config(noreplace) %{_sysconfdir}/selinux/%1/contexts/users/staff_u \
%dir %{_datadir}/selinux/%1 \
%dir %{_datadir}/selinux/packages/%1 \
%{_datadir}/selinux/%1/base.lst \
%{_datadir}/selinux/%1/modules.lst \
%{_datadir}/selinux/%1/nonbasemodules.lst \
%dir %{_sharedstatedir}/selinux/%1 \
%{_sharedstatedir}/selinux/%1/active/commit_num \
%{_sharedstatedir}/selinux/%1/active/users_extra \
%{_sharedstatedir}/selinux/%1/active/homedir_template \
%{_sharedstatedir}/selinux/%1/active/seusers \
%{_sharedstatedir}/selinux/%1/active/file_contexts \
%{_sharedstatedir}/selinux/%1/active/policy.kern \
%{_sharedstatedir}/selinux/%1/active/modules_checksum \
%ghost %{_sharedstatedir}/selinux/%1/active/policy.linked \
%ghost %{_sharedstatedir}/selinux/%1/active/seusers.linked \
%ghost %{_sharedstatedir}/selinux/%1/active/users_extra.linked \
%verify(not md5 size mtime) %{_sharedstatedir}/selinux/%1/active/file_contexts.homedirs \
%nil

%define relabel() \
. %{_sysconfdir}/selinux/config; \
FILE_CONTEXT=%{_sysconfdir}/selinux/%1/contexts/files/file_contexts; \
if selinuxenabled; then \
  if [ $? = 0  -a "${SELINUXTYPE}" = %1 -a -f ${FILE_CONTEXT}.pre ]; then \
    %{_sbindir}/fixfiles -C ${FILE_CONTEXT}.pre restore 2> /dev/null; \
    rm -f ${FILE_CONTEXT}.pre; \
  fi; \
  if /sbin/restorecon -e /run/media -R /root /var/log /var/run %{_sysconfdir}/passwd* %{_sysconfdir}/group* %{_sysconfdir}/*shadow* 2> /dev/null;then \
    continue; \
  fi; \
fi;

%define preInstall() \
if [ $1 -ne 1 ] && [ -s %{_sysconfdir}/selinux/config ]; then \
     . %{_sysconfdir}/selinux/config; \
     FILE_CONTEXT=%{_sysconfdir}/selinux/%1/contexts/files/file_contexts; \
     if [ "${SELINUXTYPE}" = %1 -a -f ${FILE_CONTEXT} ]; then \
        [ -f ${FILE_CONTEXT}.pre ] || cp -f ${FILE_CONTEXT} ${FILE_CONTEXT}.pre; \
     fi; \
     touch %{_sysconfdir}/selinux/%1/.rebuild; \
     if [ -e %{_sysconfdir}/selinux/%1/.policy.sha512 ]; then \
        POLICY_FILE=`ls %{_sysconfdir}/selinux/%1/policy/policy.* | sort | head -1` \
        sha512=`sha512sum $POLICY_FILE | cut -d ' ' -f 1`; \
        checksha512=`cat %{_sysconfdir}/selinux/%1/.policy.sha512`; \
        if [ "$sha512" == "$checksha512" ] ; then \
                rm %{_sysconfdir}/selinux/%1/.rebuild; \
        fi; \
   fi; \
fi;

%define postInstall() \
. %{_sysconfdir}/selinux/config; \
if [ -e %{_sysconfdir}/selinux/%2/.rebuild ]; then \
  rm %{_sysconfdir}/selinux/%2/.rebuild; \
  /usr/sbin/semodule -B -n -s %2 2> /dev/null; \
fi; \
if [ -n "${TRANSACTIONAL_UPDATE}" ]; then \
  touch /etc/selinux/.autorelabel \
else    \
  if [ "${SELINUXTYPE}" = "%2" ]; then \
    if selinuxenabled; then \
      load_policy; \
    else \
      # probably a first install of the policy \
      true; \
    fi; \
  fi; \
  if selinuxenabled; then \
    if [ %1 -eq 1 ]; then \
      /sbin/restorecon -R /root /var/log /run /etc/passwd* /etc/group* /etc/*shadow* 2> /dev/null; \
    else \
      %relabel %2 \
    fi; \
  else \
    # run fixfiles on next boot \
    touch /.autorelabel \
  fi; \
fi;

%define modulesList() \
awk '$1 !~ "/^#/" && $2 == "=" && $3 == "module" { printf "%%s ", $1 }' ./policy/modules.conf > %{buildroot}%{_datadir}/selinux/%1/modules.lst \
awk '$1 !~ "/^#/" && $2 == "=" && $3 == "base" { printf "%%s ", $1 }' ./policy/modules.conf > %{buildroot}%{_datadir}/selinux/%1/base.lst \

%define nonBaseModulesList() \
modules=`cat %{buildroot}%{_datadir}/selinux/%1/modules.lst` \
for i in $modules; do \
    if [ $i != "sandbox" ];then \
        echo "%verify(not md5 size mtime) %{_sharedstatedir}/selinux/%1/active/modules/100/$i" >> %{buildroot}%{_datadir}/selinux/%1/nonbasemodules.lst \
    fi; \
done;

%description
A complete SELinux policy that can be used as the system policy for a variety
of systems and used as the basis for creating other policies.

%files
%defattr(-,root,root,-)
%license COPYING
%dir %{_datadir}/selinux
%dir %{_datadir}/selinux/packages
%dir %{_sysconfdir}/selinux
%ghost %config(noreplace) %{_sysconfdir}/selinux/config
%{_tmpfilesdir}/selinux-policy.conf
%{_rpmconfigdir}/macros.d/macros.selinux-policy

%package sandbox
Summary:        SELinux policy sandbox
Group:          System/Management
Requires(pre):  selinux-policy-targeted = %{version}-%{release}

%description sandbox
SELinux sandbox policy used for the policycoreutils-sandbox package

%files sandbox
%verify(not md5 size mtime) %{_datadir}/selinux/packages/sandbox.pp

%post sandbox
rm -f %{_sysconfdir}/selinux/*/modules/active/modules/sandbox.pp.disabled 2>/dev/null
rm -f %{_sharedstatedir}/selinux/*/active/modules/disabled/sandbox 2>/dev/null
%{_sbindir}/semodule -n -X 100 -i %{_datadir}/selinux/packages/sandbox.pp 2> /dev/null
if %{_sbindir}/selinuxenabled ; then
    %{_sbindir}/load_policy
fi;
exit 0

%preun sandbox
if [ $1 -eq 0 ] ; then
    %{_sbindir}/semodule -n -d sandbox 2>/dev/null
    if %{_sbindir}/selinuxenabled ; then
        %{_sbindir}/load_policy
    fi;
fi;
exit 0

%prep

# set up selinux-policy
%autosetup -n %{name}-%{version} -p1

# dirty hack for container-selinux, because selinux-policy won't build without it
# upstream does not want to include it in main policy tree:
# see discussion in https://github.com/containers/container-selinux/issues/186
for i in %{SOURCE1} %{SOURCE2} %{SOURCE3}; do
  cp $i policy/modules/services/
done

%build

%install
mkdir -p %{buildroot}%{_sysconfdir}/selinux
touch %{buildroot}%{_sysconfdir}/selinux/config
mkdir -p %{buildroot}%{_tmpfilesdir}
cp %{SOURCE60} %{buildroot}%{_tmpfilesdir}

# Adjust and install RPM macro file
mkdir -p %{buildroot}%{_rpmconfigdir}/macros.d
install -m 644 %{SOURCE95} %{buildroot}%{_rpmconfigdir}/macros.d/
sed -i 's|SELINUXPOLICYVERSION|%{version}-%{release}|' %{buildroot}%{_rpmconfigdir}/macros.d/macros.selinux-policy
sed -i 's|SELINUXSTOREPATH|%{_sharedstatedir}/selinux|' %{buildroot}%{_rpmconfigdir}/macros.d/macros.selinux-policy

# Always create policy module package directories
mkdir -p %{buildroot}%{_datadir}/selinux/{targeted,mls,minimum,modules}/
mkdir -p %{buildroot}%{_sharedstatedir}/selinux/{targeted,mls,minimum,modules}/

mkdir -p %{buildroot}%{_datadir}/selinux/packages/{targeted,mls,minimum,modules}/

make clean
%if %{BUILD_TARGETED}
%makeCmds targeted mcs allow
%makeModulesConf targeted
%installCmds targeted mcs allow
# recreate sandbox.pp
rm -rf %{buildroot}%{_sharedstatedir}/selinux/targeted/active/modules/100/sandbox
%make_build %common_params UNK_PERMS=allow NAME=targeted TYPE=mcs sandbox.pp
mv sandbox.pp %{buildroot}%{_datadir}/selinux/packages/sandbox.pp
%modulesList targeted
%nonBaseModulesList targeted
%endif

%if %{BUILD_MINIMUM}
%makeCmds minimum mcs allow
%makeModulesConf targeted
%installCmds minimum mcs allow
# Sandbox is only targeted
rm -f %{buildroot}%{_sysconfdir}/selinux/minimum/modules/active/modules/sandbox.pp
rm -rf %{buildroot}%{_sharedstatedir}/selinux/minimum/active/modules/100/sandbox
install -p -m 644 %{SOURCE18} %{buildroot}%{_datadir}/selinux/minimum/modules-enabled.lst
%modulesList minimum
%nonBaseModulesList minimum
%endif

%if %{BUILD_MLS}
%makeCmds mls mls deny
%makeModulesConf mls
%installCmds mls mls deny
%modulesList mls
%nonBaseModulesList mls
%endif

# Install devel
mkdir -p %{buildroot}%{_mandir}
cp -R  man/* %{buildroot}%{_mandir}
make %common_params UNK_PERMS=allow NAME=targeted TYPE=mcs DESTDIR=%{buildroot} PKGNAME=%{name} install-docs
make %common_params UNK_PERMS=allow NAME=targeted TYPE=mcs DESTDIR=%{buildroot} PKGNAME=%{name} install-headers
mkdir %{buildroot}%{_datadir}/selinux/devel/
mv %{buildroot}%{_datadir}/selinux/targeted/include %{buildroot}%{_datadir}/selinux/devel/include
install -m 644 %{SOURCE91} %{buildroot}%{_datadir}/selinux/devel/Makefile
install -m 644 doc/example.* %{buildroot}%{_datadir}/selinux/devel/
install -m 644 doc/policy.* %{buildroot}%{_datadir}/selinux/devel/
%{_bindir}/sepolicy manpage -a -p %{buildroot}%{_datadir}/man/man8/ -w -r %{buildroot}
mkdir %{buildroot}%{_datadir}/selinux/devel/html
mv %{buildroot}%{_datadir}/man/man8/*.html %{buildroot}%{_datadir}/selinux/devel/html
mv %{buildroot}%{_datadir}/man/man8/style.css %{buildroot}%{_datadir}/selinux/devel/html
rm %{buildroot}%{_mandir}/man8/container_selinux.8*
rm %{buildroot}%{_datadir}/selinux/devel/include/services/container.if

%post
if [ ! -s %{_sysconfdir}/selinux/config ]; then
    # new install, use old sysconfig file if that exists,
    # else create new one.
    if [ -f  %{_sysconfdir}/sysconfig/selinux-policy ]; then
	mv %{_sysconfdir}/sysconfig/selinux-policy %{_sysconfdir}/selinux/config
    else
	echo "
# This file controls the state of SELinux on the system.
# SELinux can be completly disabled with the \"selinux=0\" kernel
# commandline option.
#
# SELINUX= can take one of these three values:
#     enforcing  - SELinux security policy is enforced.
#     permissive - SELinux prints warnings instead of enforcing.
#     disabled   - SELinux is disabled
SELINUX=permissive
# SELINUXTYPE= can take one of these three values:
#     targeted - Targeted processes are protected,
#     minimum - Modification of targeted policy. Only selected processes are protected.
#     mls - Multi Level Security protection.
SELINUXTYPE=targeted

" > %{_sysconfdir}/selinux/config
    fi
    ln -sf ../selinux/config %{_sysconfdir}/sysconfig/selinux-policy
    %{_sbindir}/restorecon %{_sysconfdir}/selinux/config 2> /dev/null || :
fi
%tmpfiles_create %_tmpfilesdir/selinux-policy.conf
if [ $1 -eq 1 ]; then
  pam-config -a --selinux
fi
exit 0

%define post_un() \
# disable selinux if we uninstall a policy and it's the used one \
if [ $1 -eq 0 ]; then \
  if [ -s %{_sysconfdir}/selinux/config ]; then \
      source %{_sysconfdir}/selinux/config &> /dev/null || true \
  fi \
  if [ "$SELINUXTYPE" = "$2" ]; then \
    %{_sbindir}/setenforce 0 2> /dev/null \
    if [ -s %{_sysconfdir}/selinux/config ]; then \
      sed -i 's/^SELINUX=.*/SELINUX=permissive/g' %{_sysconfdir}/selinux/config \
    fi \
  fi \
  pam-config -d --selinux \
fi \
exit 0

%postun
if [ $1 = 0 ]; then
     %{_sbindir}/setenforce 0 2> /dev/null
     if [ -s %{_sysconfdir}/selinux/config ]; then
          sed -i 's/^SELINUX=.*/SELINUX=permissive/g' %{_sysconfdir}/selinux/config
     fi
fi
exit 0

%package devel
Summary:        SELinux policy devel
Group:          System/Management
Requires(pre):  selinux-policy = %{version}-%{release}
Requires:       /usr/bin/make
Requires:       checkpolicy >= %{CHECKPOLICYVER}
Requires:       m4

%description devel
SELinux policy development and man page package

%files devel
%defattr(-,root,root,-)
%doc %{_datadir}/man/ru/man8/*
%doc %{_datadir}/man/man8/*
%dir %{_datadir}/selinux/devel
%dir %{_datadir}/selinux/devel/html/
%doc %{_datadir}/selinux/devel/html/*
%dir %{_datadir}/selinux/devel/include
%{_datadir}/selinux/devel/include/*
%{_datadir}/selinux/devel/Makefile
%{_datadir}/selinux/devel/example.*

%package doc
Summary:        SELinux policy documentation
Group:          System/Management
Requires(pre):  selinux-policy = %{version}-%{release}
Requires:       /usr/bin/xdg-open

%description doc
SELinux policy documentation package

%files doc
%defattr(-,root,root,-)
%doc %{_datadir}/doc/%{name}
%{_datadir}/selinux/devel/policy.*

%if %{BUILD_TARGETED}
%package targeted
Summary:        SELinux targeted base policy
Group:          System/Management
Provides:       selinux-policy-base = %{version}-%{release}
Requires(pre):  coreutils
Requires(pre):  selinux-policy = %{version}-%{release}
Requires:       selinux-policy = %{version}-%{release}

%description targeted
SELinux policy targeted base module.

%pre targeted
%preInstall targeted

%posttrans targeted
%postInstall $1 targeted
exit 0

%postun targeted
%post_un $1 targeted

%triggerin -- libpcre2-8-0
%{_sbindir}/selinuxenabled && %{_sbindir}/semodule -nB 2> /dev/null
exit 0

%files targeted -f %{buildroot}%{_datadir}/selinux/targeted/nonbasemodules.lst
%config(noreplace) %{_sysconfdir}/selinux/targeted/contexts/users/unconfined_u
%config(noreplace) %{_sysconfdir}/selinux/targeted/contexts/users/sysadm_u
%fileList targeted
%endif

%if %{BUILD_MINIMUM}
%package minimum
Summary:        SELinux minimum base policy
Group:          System/Management
Provides:       selinux-policy-base = %{version}-%{release}
Requires(post): policycoreutils >= %{POLICYCOREUTILSVER}
Requires(post): policycoreutils-python-utils >= %{POLICYCOREUTILSVER}
Requires(pre):  coreutils
Requires(pre):  /usr/bin/awk
Requires(pre):  selinux-policy = %{version}-%{release}
Requires:       selinux-policy = %{version}-%{release}

%description minimum
SELinux policy minimum base module.

%pre minimum
%preInstall minimum
if [ $1 -ne 1 ]; then
    %{_sbindir}/semodule -s minimum --list-modules=full | awk '{ if ($4 != "disabled") print $2; }' > %{_datadir}/selinux/minimum/instmodules.lst
fi

%post minimum
modules=`cat %{_datadir}/selinux/minimum/modules.lst`
basemodules=`cat %{_datadir}/selinux/minimum/base.lst`
enabledmodules=`cat %{_datadir}/selinux/minimum/modules-enabled.lst`
if [ ! -d %{_sharedstatedir}/selinux/minimum/active/modules/disabled ]; then
    mkdir %{_sharedstatedir}/selinux/minimum/active/modules/disabled
fi
if [ $1 -eq 1 ]; then
for p in $modules; do
    touch %{_sharedstatedir}/selinux/minimum/active/modules/disabled/$p
done
for p in $basemodules $enabledmodules; do
    rm -f %{_sharedstatedir}/selinux/minimum/active/modules/disabled/$p
done
    %{_sbindir}/semanage import -S minimum -f - << __eof
login -m  -s unconfined_u -r s0-s0:c0.c1023 __default__
login -m  -s unconfined_u -r s0-s0:c0.c1023 root
__eof
    /sbin/restorecon -R /root /var/log /var/run 2> /dev/null
    %{_sbindir}/semodule -B -s minimum 2> /dev/null
else
    instpackages=`cat %{_datadir}/selinux/minimum/instmodules.lst`
    for p in $packages; do
	touch %{_sharedstatedir}/selinux/minimum/active/modules/disabled/$p
    done
    for p in $instpackages snapper dbus kerberos nscd rtkit; do
	rm -f %{_sharedstatedir}/selinux/minimum/active/modules/disabled/$p
    done
    %{_sbindir}/semodule -B -s minimum 2> /dev/null
    %relabel minimum
fi
exit 0

%postun minimum
%post_un $1 minimum

%files minimum -f %{buildroot}%{_datadir}/selinux/minimum/nonbasemodules.lst
%config(noreplace) %{_sysconfdir}/selinux/minimum/contexts/users/unconfined_u
%config(noreplace) %{_sysconfdir}/selinux/minimum/contexts/users/sysadm_u
%{_datadir}/selinux/minimum/modules-enabled.lst
%fileList minimum
%endif

%if %{BUILD_MLS}
%package mls
Summary:        SELinux mls base policy
Group:          System/Management
Provides:       selinux-policy-base = %{version}-%{release}
Requires:       policycoreutils-newrole >= %{POLICYCOREUTILSVER}
Requires:       setransd
Requires(pre):  policycoreutils >= %{POLICYCOREUTILSVER}
Requires(pre):  coreutils
Requires(pre):  selinux-policy = %{version}-%{release}
Requires:       selinux-policy = %{version}-%{release}

%description mls
SELinux policy mls base module.

%pre mls
%preInstall mls

%posttrans mls
%postInstall $1 mls

%postun mls
%post_un $1 mls

%files mls -f %{buildroot}%{_datadir}/selinux/mls/nonbasemodules.lst
%config(noreplace) %{_sysconfdir}/selinux/mls/contexts/users/unconfined_u
%fileList mls
%endif

%changelog
* Wed Jul 16 2025 cathy.hu@suse.com
- Update to version 20250627+git62.68c403828:
  * Allow virtqemud_t use its private tmpfs files (bsc#1242998)
  * Allow virtqemud_t setattr to /dev/userfaultfd (bsc#1242998)
  * Allow virtqemud_t read and write /dev/ptmx (bsc#1242998)
  * Extend virtqemud_t tcp_socket permissions (bsc#1242998)
  * Mark configfs_t as mountpoint (bsc#1246080)
  * healthchecker: add proper optional_policy() guards
  * Allow virtqemud_t to read and write generic pty (bsc#1242998)
  * Drop SUSE-specific /usr/etc = /etc equivalency
  * Allow irqbalance execute shell if irqbalance_run_unconfined is on
  * Allow openvswitch ioctl vduse devices
  * Label /dev/vduse/control and /dev/vduse/NAME devices
  * Allow virtstoraged the sys_rawio capability
  * Allow virtqemud read insights-core state files
  * Allow virtnodedev create mdevctl config dirs
  * Allow virtqemud additional permissions on scsi generic chr files
  * Allow local login execute gnome keyring daemon
  * Allow plymouthd_t read proc files of systemd_passwd_agent (bsc#1245470)
  * Allow virtqemud send a generic signal to passt
  * Allow svirt-tcg read init state
  * Allow irqbalance execute shell if irqbalance_run_unconfined is on
  * Label /run/opendkim with dkim_milter_data_t
  * Allow sa-update status systemd services
  * Introduce new cluster_service_transition_to_unconfined_user boolean (bsc#1244495)
  * Allow updpwd logging send audit messages
  * Temporary dontaudit iio-sensor-proxy sys_admin.
  * Allow iio-sensor-proxy sendto to journald over a unix datagram socket
  * Revert "Allow iio-sensor-proxy sendto to journald over a unix datagram socket"
  * virt: allow QEMU use of the qgs daemon for attestation
  * qgs: add contrib module for TDX "qgs" daemon
  * kernel: add interfaces for using SGX enclaves
  * Define file equivalency for /usr/etc
  * Allow mongod to receive pressure stall information
  * Dontaudit systemd_generator read sssd public files
  * Allow plymouthd read/write input event devices
  * Label 99-nvme-nbft-connect.sh with NetworkManager_dispatcher_nvme_script_t
  * Allow systemd-user-runtime-dir sendto to syslogd
  * Remove pcp module
  * Update irqbalance policy for using unconfined scripts
  * Allow utempter use terminal multiplexor
  * Allow virtqemud execute ovs-vsctl with a domain transition
  * Update the files_search_mnt() interface
  * Allow nmbd read network sysctls
  * Allow iio-sensor-proxy sendto to journald over a unix datagram socket
  * Allow logrotate stop all systemd services
  * systemd: rework systemd_manage_random_seed
  * Allow tuned-ppd connect to sssd over a unix stream socket
  * Drop config for /run/random-seed
  * Update file location for systemd random-seed file
  * Allow tomcat execute cracklib-check with a domain transition
  * Allow sssd watch lib dirs
  * Confine systemd-hibernate-resume
  * Allow login_userdomain create /run/tlog directory with user_tmp_t
  * Allow login_pgm read filesystem sysctls
  * Allow gconfd connect to system dbus
  * Allow NetworkManager manage NetworkManager_etc_rw_t symlinks
- Syncing with upstream rawhide selinux-policy up to:
  * 23514206ea45e1d1d2f8a4c08288065c813fcc91
- Update embedded container-selinux version to commit:
  * 36e8f213b7ac8a1843e5e37b37eb8ef7bdc2af9c (version 2.238.0)
* Fri Jun 27 2025 cathy.hu@suse.com
- Update to version 20250627+git0.1805634d:
  * Set /srv/www = /var/www as equivalent file context (bsc#1239177)
  * Add a smoke test to the gitlab-ci
  * Add a default PR template
  * allow openvpn to attach to wicked owned tun interfaces (bsc#1243291)
  * allow wicked to connect to networkmanager and mange pid files for it (bsc#1243291)
  * allow wicked to transition to openvswitch domain (bsc#1243291)
  * allow wicked to start systemd services (bsc#1243291)
  * allow wicked to controll firewalld services (bsc1243291)
  * allow wicked interaction with tmpfs files and creation of sysfs files (bsc#1243291)
  * introduce fs_dontaudit_exec_tmpfs_files interface
  * Trigger the gitlab-ci tests only for merge requests to factory
  * Move 'logging_mounton_syslog_pid_socket' to end of file
  * Revert "Allow init_t create syslog files (bsc#1230134)"
  * Allow mdadm nosuid_transition
  * Label plasma user service files as xdm_unit_file_t.
  * Revert "Allow systemd-homed to start services."
  * Allow virtstoraged write qemu runtime files
  * Allow virtqemud read/write/setattr input event devices
  * Allow systemd create journal pid files
  * Allow networkmanager send a general signal to iptables
  * Allow syslogd watch syslog_conf_t directories
  * Revert downstream fix for bsc#1199630 due to regression (bsc#1243242)
  * Allow systemd-machined work with its private tmp and tmpfs files
  * Allow geoclue read virt lib files
  * Fix files_dontaudit_delete_all_files()
  * Label /run/polkit-1 with policykit_var_run_t
  * Label /dev/diag as diagnostic_device_t
  * Allow systemd-homed to start services.
  * Allow named_t to read NetworkManager's runtime files
  * Improve README* documentation
  * Add missing permissions for ftpd_anon_write to manage NFS directories
  * Add missing permissions for ftpd_anon_write to manage CIFS directories
  * Allow nut-upsmon write systemd inhibit pipes
  * Allow systemd-user-runtime-dir connect to systemd-userdbd over a unix socket
  * Remove permissive domain for systemd_vsftpd_generator_t
  * Change generator-specific rules to apply to systemd_generator
  * Define file equivalency for /var/etc
  * Allow tuned-ppd create ppd_base_profile with a file transition
  * Allow lldpd connect to systemd-homed over a unix socket
  * Allow sysadm_sudo_t signal rpm script
  * Fix the "/var/cache/systemd/home(/.*)?" regex
  * allow selinux_autorelabel_generator_t dac_read_search (bsc#1237511)
  * do not set sulogin_no_pam (bsc#1237511)
- Replace internal slfo-main git branch with factory
* Mon May 12 2025 rfrohl@suse.com
- Update to version 20241031+git652.e1d5a07e:
  * healthchecker: allow capability sys_admin (bsc#1240138)
  * Enable mysql_run_under_different_user for (open)SUSE (bsc#1240949)
  * Introduce mysql_run_under_different_user boolean (bsc#1240949)
  * Revert "Set mysqld_t permissive until we have tested it thorougly (bsc#1240949)"
  * slapd needs dac_override for ldapi socket (bsc#1242252)
  * Allow slapd_t nnp_transition for NoNewPrivileges (bsc#1242252)
  * Allow snapper_tu_etc_plugin_t fowner (bsc#1242768)
  * Allow snapper_tu_etc_plugin_t dac_override (bsc#1242768)
  * Revert "add dev_watch_sysfs_dirs interface"
  * Revert "Allow journalctl read messages from /var/lib/machines (bsc#1235829)"
  * Revert "Allow xenstored_t manage xend_var_lib_t files (bsc#1228540)"
  * label start script for pcp logger properly (bsc#1241611)
  * Allow collectd accept and listen to tcp sockets
  * healthchecker: fix findmnt with encrypted disks (bsc#1238606)
  * Allow cluster_t use NoNewPrivileges systemd hardening (bsc#1241921)
  * dontaudit sys_resource for NetworkManager_dispatcher types (bsc#1241888)
  * Allow init_t nnp domain transition to redis_t
  * Allow tlshd read network sysctls
  * Allow NetworkManager create and use icmp_socket
  * Allow varnishd execute the prlimit64() syscall
  * Allow rhsmcertd connect to systemd-machined
  * Allow virt_domain write to virt_image_t files
  * Allow system-dbusd list systemd-machined directories
  * Allow asterisk read network sysctls
  * Allow virtstoraged fsetid capability
  * Allow xdm watch a mnt_t directory
  * Allow collectd bind TCP sockets to the collectd port
  * Allow virtqemud relabel from tmpfs lnk files
  * Allow gnome-remote-desktop additional sockets permissions
  * Update insights-core policy
  * Update systemd-homed policy
  * Allow xenstored_t manage xend_var_lib_t files (bsc#1228540)
  * Allow init and login_pgm connect to systemd-logind over a unix socket
  * Allow login_userdomain read pressure stall information
  * Allow systemd-journald create and use vsock socket
  * Update systemd-pcrextend policy
  * Allow systemd watch/watch_reads usb ttys
  * Update coreos-installer-generator policy
  * Update systemd-homed policy
  * Allow systemd-user-runtime-dir get/set tmpfs quotas
  * Allow systemd-rfkill read nsfs files
  * Dontaudit bootc-systemd-generator search sssd lib directories
  * Allow systemd-user-runtime-dir delete gnome homedir content
  * allows gssd_t to read nfs symlinks (bsc#1241042)
  * Allow tuned-ppd read sssd public files
  * Allow tuned-ppd watch_reads sysfs directories
  * Confine /usr/lib/systemd/systemd-user-runtime-dir
  * Revert "Dontaudit systemd-logind remove all files"
  * Make bootupd use bootupd_tmp_t as its private type for files in /tmp
  * Label SetroubleshootPrivileged.py with setroubleshootd_exec_t
  * Allow power-profiles-daemon watch sysfs directories
  * systemd: allow reading /dev/cpu/0/msr
  * Update the pcmsensor policy
  * Allow chronyd-restricted sendto to chronyc
  * Allow system_dbusd_t r/w unix stream sockets of unconfined_service_t
  * Allow dovecot-deliver read mail aliases
  * Confine systemd-factory-reset system generator
  * Allow systemd debug generator read tmpfs files
  * Allow gnome-shell get attributes of systemd inhibit pipes
  * Allow tuned-ppd watch sysfs directories
  * Fix the storage_rw_inherited_removable_device() interface
  * Allow sadc read global pressure stall information
  * Allow virtqemud read sblim-gatherd process state
- Update embedded container-selinux version to commit:
  * d7e420a1166c8bd237a7877f76fa9a0e484a7c68 (version 2.237.0)
* Tue Apr 29 2025 cathy.hu@suse.com
- Update to version 20241031+git575.74e21c8b:
  * Allow cluster_t use NoNewPrivileges systemd hardening (bsc#1241921)
* Wed Apr 16 2025 rfrohl@suse.com
- Update to version 20241031+git573.66b1ba94:
  * allows gssd_t to read nfs symlinks (bsc#1241042)
  * Label tpm2-measure.log with systemd_pcrlock_var_lib_t (bsc#1240887)
  * Introduce unconfined mysqld_systemd_helper_t (bsc#1240949)
  * Set mysqld_t permissive until we have tested it thorougly (bsc#1240949)
  * Fix label of mysqld (bsc#1240949)
  * Allow login to podman container from tty (1238709)
  * Initial policy for snapper 50-etc plugin (bsc#1236671)
  * Add an rpmbuild test to the gitlab-ci
  * Allow hyper-v's fcopy_uio_daemon to run as unconfined_service_t (bsc#1239593)
  * Allow switcheroo-control dbus chat with xdm
  * Fix typo in calling unconfined_dbus_chat for switcheroo-control
  * Allow sysadm_t to write to /dev/kmsg
  * Allow init_t nnp domain transition to pcscd_t
  * Fix the genfscon statement for pidfs filesystem
  * Allow tuned-ppd dbus chat with xdm
  * Update INSTALL to describe necessary steps to build it
  * Rename the default policy to fedora-selinux
  * Update COPYING to the latest version of GPLv2
  * Allow traceroute_t bind rawip sockets to unreserved ports
  * Revert "Allow traceroute_t bind rawip sockets to unreserved ports"
  * Change the bootc system generator name to bootc-systemd-generator
  * Correct path for SAP HDB binary
  * additional path for SAP binaries
  * Allow xenstored_t manage xend_var_lib_t files (bsc#1228540)
  * dontaudit access to /etc/passwd for power-profiles-daemon (bsc#1237534)
  * allow power-profiles-daemon to watch sysfs directories (bsc#1237534)
  * add dev_watch_sysfs_dirs interface
  * Allow mpd use the io_uring API
  * Confine tuned-ppd
  * Add the switcheroo module
  * Label wine's windows libraries as textrel_shlib_t
  * Allow systemd domains write global pressure stall information
  * Add label and interfaces for kernel PSI files
  * Update bootupd policy
  * Update ktls policy
  * Add policy for systemd-bootc-generator
  * Allow blueman the kill capability
  * Add context for plymouth debug log files
  * Allow rlimit inheritance for domains transitioning to local_login_t
  * Update insights-core policy
  * Allow insights-core map all non-security files
  * Allow insights-core map audit config and log files
  * Allow insights-client manage insights_client_var_log_t files
- Update embedded container-selinux version to commit:
  * 4244f856ea34d20edb903a6ff28667400a4b6c18 (version 2.236.0)
* Thu Mar 20 2025 rfrohl@suse.com
- Update to version 20241031+git516.1a75276b:
  * rebootmgr: Handle config under /etc/rebootmgr (bsc#1239720)
  * health-checker-plugin: Move from dbus to varlink for rebootmgr communication (bsc#1237273)
  * Introduce rebootmgr_var_run_t for files under run (bsc#1237273)
  * Adjust to correct new binary path (bsc#1237273)
  * health-checker: allow snapshot rollback (bsc#1235860)
  * snapper: add interface to select the next boot snapshot
  * Label wine's windows libraries as textrel_shlib_t (bsc#1239317)
  * Allow auth_use_pam to create /var/lib/wtmpdb (bsc#1237513)
  * initial labeling for Hana systems
  * allow ping to bind generic UDP nodes
  * allow systemd_pcrlock_t to manage dos directories (bsc#1233358)
  * Allow snapper to manage dos files and dontaudit execmem (bsc#1233358)
  * enabled filed name transitions for systemd_pcrlock (bsc#1233358)
  * Update kmscon policy module to kmscon version 9 (bsc#1238137)
  * Revert "Allow systemd-networkd to rw memfd objects in tmpfs (bsc#1237515)"
  * Label /var/log/php-fpm.log httpd_log_t (bsc#1238403)
  * Allow systemd-networkd to rw memfd objects in tmpfs (bsc#1237515)
  * Add a gitlab-ci build test
  * allow ssh-keygen to connect to the ssh daemon via vsockets (bsc#1238191)
  * Add context for plymouth debug log files (bsc#1237440)
  * Remove duplicate dev_rw_dma_dev(xdm_t)
  * Allow thumbnailer read and write the dma device
  * Allow named_filetrans_domain filetrans raid/mdadm named content
  * Allow afterburn to mount and read config drives
  * dist/targeted/modules.conf: Enable kmscon module (bsc#1238137)
  * Allow mptcpd the net_admin capability
  * label apache2 binaries correctly (bsc#1237596)
  * Label /run/systemd/pcrlock.json systemd_pcrlock_var_lib_t
  * systemd_pcrlock_t needs to filetrans when recreating /var/lib/pcrlock.d
  * Allow snapper access to keys
  * Add rules for pcrlock (bsc#1233358)
  * allow snapper to call pcrlock and manage its files
  * allow unconfined_t to execute pcrlock
  * label rules for default systemd_pcrlock_var_lib_t locations
  * new interfaces: systemd_domtrans_pcrlock and systemd_pcrlock_exec
  * introduce systemd_pcrlock_var_lib_t and systemd_manage_pcrlock_files
  * Introduce interfaces snapper_manage_tmp_files and snapper_manage_tmp_dirs
  * Allow named_filetrans_domain filetrans raid/mdadm named content (bsc#1236807)
  * Grant privoxy_t the sys_chroot capability (bsc#1237375)
  * Allow init_t nnp_transition to tor_t (bsc#1237375)
  * Allow systemd-networkd the sys_admin capability
  * Update systemd-networkd policy in systemd v257
  * Separate insights-core from insights-client
  * Removed unused insights_client interfaces calls from other modules
  * Update policy for insights_client wrt new rules for insights_core_t
  * Add policy for insights-core
  * Allow systemd-networkd use its private tmpfs files
  * Allow boothd connect to systemd-machined over a unix socket
  * Update init_explicit_domain() interface
  * Allow tlp to read/write nmi_watchdog state information
  * Allow power-profiles-daemon the bpf capability
  * Allow svirt_t to connect to nbdkit over a unix stream socket
  * Update ktlshd policy to read /proc/keys and domain keyrings
  * Allow virt_domain read hardware state information unconditionally
  * Allow init mounton crypto sysctl files
  * Rename winbind_rpcd_* types to samba_dcerpcd_*
  * Support peer-to-peer migration of vms using ssh
  * Allow virtqemud use hostdev usb devices conditionally
  * Allow virtqemud map svirt_image_t plain files
  * Allow virtqemud work with nvdimm devices
  * Support saving and restoring a VM to/from a block device
  * Allow virtnwfilterd dbus chat with firewalld
- Update embedded container-selinux version to commit:
  * c9b3eca0e1a878a1fe79408cb6c2e89b38b10829
* Tue Feb 25 2025 cathy.hu@suse.com
- Update to version 20240604+git813.a995c5c8:
  * Label /run/systemd/pcrlock.json systemd_pcrlock_var_lib_t
  * systemd_pcrlock_t needs to filetrans when recreating /var/lib/pcrlock.d
  * Allow snapper access to keys
  * Add rules for pcrlock (bsc#1233358)
  * allow snapper to call pcrlock and manage its files
  * allow unconfined_t to execute pcrlock
  * label rules for default systemd_pcrlock_var_lib_t locations
  * new interfaces: systemd_domtrans_pcrlock and systemd_pcrlock_exec
  * introduce systemd_pcrlock_var_lib_t and systemd_manage_pcrlock_files
  * Introduce interfaces snapper_manage_tmp_files and snapper_manage_tmp_dirs
* Fri Feb 21 2025 cathy.hu@suse.com
- Update to version 20240604+git802.bedfc504:
  * Allow named_filetrans_domain filetrans raid/mdadm named content (bsc#1236807)
* Wed Feb 19 2025 cathy.hu@suse.com
- Update to version 20240604+git800.2adbf625:
  * Enable postfix_local_write_mail_spool boolean by default for targeted only
  * Revert "Enable postfix_local_write_mail_spool boolean by default"
  * Support openSUSE-specific krb5kdc paths (bsc#1237064)
  * Allow rlimit inheritance for domains transitioning to local_login_t
  * Enable postfix_local_write_mail_spool boolean by default
  * kanidm_unixd.fc: follow default style for aliased paths
  * Dontaudit systemd-logind remove all files
  * Add the files_dontaudit_read_all_dirs() interface
  * Add the files_dontaudit_delete_all_files() interface
  * Allow rhsmcertd notify virt-who
  * Allow irqbalance to run unconfined scripts conditionally
  * Allow snapperd execute systemctl in the caller domain
  * Allow svirt_tcg_t to connect to nbdkit over a unix stream socket
  * Allow iio-sensor-proxy read iio devices
  * Label /dev/iio:device[0-9]+ devices
  * Allow systemd-coredump the sys_admin capability
  * Allow apcupsd's apccontrol to send messages using wall
  * contrib/thumb: also allow per-user thumbnailers
  * contrib/thumb: fix thunar thumbnailer (rhbz#2315893)
  * Allow virt_domain to use pulseaudio - conditional
  * Allow pcmsensor read nmi_watchdog state information
  * Allow init_t nnp domain transition to gssproxy_t
  * Allow quota_t load its kernel module (bsc#1235805)
  * Allow apcupsd's apccontrol to send messages using wall (bsc#1235688)
  * Allow systemd-generator connect to syslog over a unix stream socket
  * Allow virtqemud manage fixed disk device nodes
  * Allow iio-sensor-proxy connect to syslog over a unix stream socket
  * Allow virtstoraged write to sysfs files
  * Allow power-profiles-daemon write sysfs files
  * Update iiosensorproxy policy
  * Allow pcmsensor write nmi_watchdog state information
  * Label /proc/sys/kernel/nmi_watchdog with sysctl_nmi_watchdog_t
  * Allow virtnodedev create /etc/mdevctl.d/scripts.d with bin_t type
  * Add the gpg_read_user_secrets() interface
  * Dontaudit xdm_t wanting to create /root/.cache dir (bsc#1235669)
  * Allow journalctl read messages from /var/lib/machines (bsc#1235829)
  * Allow gnome-remote-desktop read resolv.conf
  * Update switcheroo policy
  * Allow nfsidmap connect to systemd-homed over a unix socket
  * wtmpdbd systemd service uses NoNewPrivileges (bsc#1235660)
  * Transition samba-dcerpcd pid file from smbd_var_run_t to winbind_var_run_t (bsc#1235801)
  * /run/samba/samba-dcerpcd.pid needs fc type winbind_rpcd_var_run_t (bsc#1235801)
  * Adjust rpcd_lsad, samba-bgqd, samba-dcerpcd to SUSE-specific part (bsc#1235801)
  * Transition nmbd pid file from smbd_var_run_t to nmbd_var_run_t (bsc#1235801)
  * Add the auth_write_motd_var_run_files() interface
  * Add the bind_exec_named_checkconf() interface
  * Add the virt_exec_virsh() interface
  * Allow database rotation for wtmpdbd_t
  * Allow wtmpdbd to send messages notifications
  * Introduce policy for wtmpdbd (bsc#1235660)
  * Label xrdp scripts in /etc as bin_t (bsc#1233738)
  * introduce unconfined_service_transition_to_unconfined_user boolean (bsc#1233738)
  * Allow virtqemud domain transition to nbdkit
  * Add nbdkit interfaces defined conditionally
  * Allow samba-bgqd connect to cupsd over an unix domain stream socket
  * Confine the switcheroo-control service
  * Allow svirt_t read sysfs files
  * Allow init to manage DOS files (bsc#1232527)
  * Add rhsmcertd interfaces
  * Add the ssh_exec_sshd() interface
  * Add the gpg_domtrans_agent() interface
  * Label /usr/bin/dnf5 with rpm_exec_t
  * Label /dev/pmem[0-9]+ with fixed_disk_device_t
  * allow kdm to create /root/.kde/ with correct label
  * Change /usr/sbin entries to use /usr/bin or remove them
  * Allow systemd-homed get filesystem quotas
  * Allow login_userdomain getattr nsfs files
  * Allow virtqemud send a generic signal to the ssh client domain
  * Dontaudit request-key read /etc/passwd
  * Update virtqemud policy regarding the svirt_tcg_t domain
  * Allow virtqemud domain transition on numad execution
  * Support virt live migration using ssh
  * Allow virtqemud permissions needed for live migration
  * Allow virtqemud the getpgid process permission
  * Allow virtqemud manage nfs dirs when virt_use_nfs boolean is on
  * Allow virtqemud relabelfrom virt_log_t files
  * Allow virtqemud relabel tun_socket
  * Add policy for systemd-import-generator
  * Confine vsftpd systemd system generator
  * Allow virtqemud read and write sgx_vepc devices
  * Allow systemd-networkd list cgroup directories
  * Allow xdm dbus chat with power-profiles-daemon
  * Allow ssh_t read systemd config files
  * Add Valkey rules to Redis module
  * Update ktlsh policy
  * Allow request-key to read /etc/passwd
  * Allow request-key to manage all domains' keys
  * Add support for the KVM guest memfd anon inodes
* Fri Feb  7 2025 rfrohl@suse.com
- Improve semodule stderr logging during install/update: Verbose logging
  will just confuse users and the policy will be rebuild later in the update
  process correctly, if there was an earlier error. These transient errors
  are only related to the order in which packages are installed.
* Mon Jan 27 2025 cathy.hu@suse.com
- Update to version 20240604+git689.da1e0e20:
  * Transition samba-dcerpcd pid file from smbd_var_run_t to winbind_var_run_t (bsc#1235801)
  * /run/samba/samba-dcerpcd.pid needs fc type winbind_rpcd_var_run_t (bsc#1235801)
  * Adjust rpcd_lsad, samba-bgqd, samba-dcerpcd to SUSE-specific part (bsc#1235801)
  * Transition nmbd pid file from smbd_var_run_t to nmbd_var_run_t (bsc#1235801)
* Tue Jan 21 2025 cathy.hu@suse.com
- Update to version 20240604+git684.814e5b91:
  * wtmpdbd systemd service uses NoNewPrivileges (bsc#1235660)
* Mon Jan 20 2025 cathy.hu@suse.com
- Update to version 20240604+git682.1bebca04:
  * Label xrdp scripts in /etc as bin_t (bsc#1233738)
  * introduce unconfined_service_transition_to_unconfined_user boolean (bsc#1233738)
  * Allow database rotation for wtmpdbd_t
  * Allow wtmpdbd to send messages notifications
  * Introduce policy for wtmpdbd (bsc#1235660)
* Thu Jan  9 2025 cathy.hu@suse.com
- Sync content of factory branch to SLFO (git commit: 33c703587e800be11fca3101b7caf2d4a5c77117,
  OBS Factory: selinux-policy-20241220) and update packaging for SLE 16.
  This includes:
  - Fix minimum policy by readding rpm module (bsc#1234314)
  - Fix minimum policy by readding snapper module (bsc#1234037)
  - Packaging rework: moving all config files to git repository
    https://gitlab.suse.de/selinux/selinux-policy
  - Moved booleans to dist/*/booleans.conf and dropped from package:
  * booleans-minimum.conf
  - user facing change: boolean settings are now the same as in upstream
  * booleans-mls.conf
  - user facing change: boolean settings are now the same as in upstream
  * booleans-targeted.conf
  - user facing change: kerberos_enabled boolean was not enabled due to a bug, now it is enabled
  - Moved booleans.subs_dist to dist/booleans.subs_dist and dropped from package
  - Moved customizable_types to dist/customizable_types and dropped from package
  - user facing change: using upstream version
  - Moved file_contexts.subs_dist to config/file_contexts.subs_dist and dropped from package
  - user facing change: changed systemd entries in file_contexts.subs_dist:
    /run/systemd/system -> dropped from file
    /run/systemd/generator.early /run/systemd/generator
    /run/systemd/generator.late /run/systemd/generator
  - Moved modules config to dist/<policytype>/modules.conf and dropped from package:
  - user facing change: minimum policy: modules base and contrib are merged into modules.lst
    and modules-enabled.lst was added which contains the enabled modules, replacing modules-minimum-disable.lst
  * modules-minimum-base.conf
  * modules-minimum-contrib.conf
  * modules-minimum-disable.lst
  * Added: modules-minimum.lst
  - user facing change: mls policy: modules base + contrib are merged into modules.lst
  * modules-mls-base.conf
  * modules-mls-contrib.conf
  - user facing change: targeted policy: modules base + contrib are merged into modules.lst:
  * modules-targeted-base.conf
  * modules-targeted-contrib.conf
  - Moved securetty config to config/appconfig-<policytype>/securetty_types and dropped from package
  - user facing change: using upstream version for all policy types
  * securetty_types-minimum
  * securetty_types-mls
  * securetty_types-targeted
  - Moved setrans config to dist/<policytype>/setrans.conf and dropped from package
  * setrans-minimum.conf
  * setrans-mls.conf
  * setrans-targeted.conf
  - Moved users config to dist/<policytype>/users and dropped from package
  * users-minimum
  - user facing change: added guest_u and xguest_u
  * users-mls
  * users-targeted
  - Fix debug-build.sh to follow symlinks when creating
    the tarball
  - Update embedded container-selinux version to commit:
  * 3f06c141bebc00a07eec4c0ded038aac4f2ae3f0
  - Sync modules-targeted-contrib.conf with Fedora targeted modules.conf
  - Disable build of the MLS policy. We currently don't know if it works
    and don't want to encourage users to apply it
  - Enable named_write_master_zones boolean by default (bsc#1229479)
- Update to version 20240604+git675.f1f499c0:
  * Revert "Remove the fail2ban module sources"
  * Revert "Remove the linuxptp module sources"
  * Revert "Remove the amtu module sources"
  * Allow vhostmd_t list virtqemud pid dirs (bsc#1230961)
  * Allow auditctl signal auditd
  * Dontaudit systemd-coredump the sys_resource capability
  * Allow traceroute_t bind rawip sockets to unreserved ports
  * Fix the cups_read_pid_files() interface to use read_files_pattern
  * Allow virtqemud additional permissions for tmpfs_t blk devices
  * Allow virtqemud rw access to svirt_image_t chr files
  * Allow virtqemud rw and setattr access to fixed block devices
  * Label /etc/mdevctl.d/scripts.d with bin_t
  * Allow virtqemud open svirt_devpts_t char files
  * Allow virtqemud relabelfrom virt_log_t files
  * Allow svirt_tcg_t read virtqemud_t fifo_files
  * Allow virtqemud rw and setattr access to sev devices
  * Allow virtqemud directly read and write to a fixed disk
  * Allow virtqemud_t relabel virt_var_lib_t files
  * Allow virtqemud_t relabel virtqemud_var_run_t sock_files
  * Add gnome_filetrans_gstreamer_admin_home_content() interface
  * Label /dev/swradio, /dev/v4l-subdev, /dev/v4l-touch with v4l_device_t
  * Make bootupd_t permissive
  * Allow init_t nnp domain transition to locate_t
  * allow gdm and iiosensorproxy talk to each other via D-bus
  * Allow systemd-journald getattr nsfs files
  * Allow sendmail to map mail server configuration files
  * Allow procmail to read mail aliases
  * Allow cifs.idmap helper to set attributes on kernel keys
  * Allow irqbalance setpcap capability in the user namespace
  * Allow sssd_selinux_manager_t the setcap process permission
  * Allow systemd-sleep manage efivarfs files
  * Allow systemd-related domains getattr nsfs files
  * Allow svirt_t the sys_rawio capability
  * Allow alsa watch generic device directories
  * Move systemd-homed interfaces to seperate optional_policy block
  * Move systemd-homed interfaces to seperate optional_policy block (bsc#1234228)
  * Update samba-bgqd policy
  * Update virtlogd policy
  * Allow svirt_t the sys_rawio capability
  * Allow qemu-ga the dac_override and dac_read_search capabilities
  * Add policy for importctl (bsc#1232670)
  * adjust kandim binary paths (bsc#1232328)
  * Allow bacula execute container in the container domain
  * Allow httpd get attributes of dirsrv unit files
  * Allow samba-bgqd read cups config files
  * Add label rshim_var_run_t for /run/rshim.pid
  * [5/5][sync from 'mysql-selinux'] Add mariadb-backup
  * [4/5][sync from 'mysql-selinux'] Fix regex to also match '/var/lib/mysql/mysqlx.sock'
  * [3/5][sync from 'mysql-selinux'] Allow mysqld_t to read and write to the 'memory.pressure' file in cgroup2
  * [2/5][sync from 'mysql-selinux'] 2nd attempt to fix rhbz#2186996 rhbz#2221433 rhbz#2245705
  * [1/5][sync from 'mysql-selinux'] Allow 'mysqld' to use '/usr/bin/hostname'
  * Allow systemd-networkd read mount pid files
  * Update policy for samba-bgqd
  * Allow chronyd read networkmanager's pid files
  * Allow staff user connect to generic tcp ports
  * Allow gnome-remote-desktop dbus chat with policykit
  * Allow tlp the setpgid process permission
  * Update the bootupd policy
  * Allow sysadm_t use the io_uring API
  * Allow sysadm user dbus chat with virt-dbus
  * Allow virtqemud_t read virsh_t files
  * Allow virt_dbus_t connect to virtd_t over a unix stream socket
  * Allow systemd-tpm2-generator read hardware state information
  * Allow coreos-installer-generator execute generic programs
  * Allow coreos-installer domain transition on udev execution
  * Add workaround for /run/rpmdb lockfile (bsc#1231127)
  * Add dedicated health-checker module (bsc#1231127)
  * Revert "Allow unconfined_t execute kmod in the kmod domain"
  * Allow iio-sensor-proxy create and use unix dgram socket
  * Allow virtstoraged read vm sysctls
  * Support ssh connections via systemd-ssh-generator
  * Label all semanage store files in /etc as semanage_store_t
  * Add file transition for nvidia-modeset
  * Re-add kanidm module to dist/targeted/modules.conf
  * Add SUSE-specific file contexts to file_contexts.subs_dist
  * Disallow execstack in dist/minimum/booleans.conf
  * Add SUSE-specific booleans to dist/targeted/booleans.conf
  * Add SUSE specific modules to targeted modules.conf
  * Label /var/cache/systemd/home with systemd_homed_cache_t
  * Allow login_userdomain connect to systemd-homed over a unix socket
  * Allow boothd connect to systemd-homed over a unix socket
  * Allow systemd-homed get attributes of a tmpfs filesystem
  * Allow abrt-dump-journal-core connect to systemd-homed over a unix socket
  * Allow aide connect to systemd-homed over a unix socket
  * Label /dev/hfi1_[0-9]+ devices
  * Remove the openct module sources
  * Remove the timidity module sources
  * Enable the slrn module
  * Remove i18n_input module sources
  * Enable the distcc module
  * Remove the ddcprobe module sources
  * Remove the timedatex module sources
  * Remove the djbdns module sources
  * Confine iio-sensor-proxy
  * Allow staff user nlmsg_write
  * Update policy for xdm with confined users
  * Allow virtnodedev watch mdevctl config dirs
  * Allow ssh watch home config dirs
  * Allow ssh map home configs files
  * Allow ssh read network sysctls
  * Allow chronyc sendto to chronyd-restricted
  * Allow cups sys_ptrace capability in the user namespace
  * Add policy for systemd-homed
  * Remove fc entry for /usr/bin/pump
  * Label /usr/bin/noping and /usr/bin/oping with ping_exec_t
  * Allow accountsd read gnome-initial-setup tmp files
  * Allow xdm write to gnome-initial-setup fifo files
  * Allow rngd read and write generic usb devices
  * Allow qatlib search the content of the kernel debugging filesystem
  * Allow qatlib connect to systemd-machined over a unix socket
  * mls/modules.conf - fix typo
  * Use dist/targeted/modules.conf in build workflow
  * Fix default and dist config files
  * Allow unprivileged user watch /run/systemd
  * CI: update to actions/checkout@v4
  * Allow boothd connect to kernel over a unix socket
  * Clean up and sync securetty_types
  * Bring config files from dist-git into the source repo
  * Confine gnome-remote-desktop
  * Allow virtstoraged execute mount programs in the mount domain
  * Make mdevctl_conf_t member of the file_type attribute
  * Allow virt_dbus_t to connect to virtd_t over unix_stream_socket (bsc#1232655)
  * Label /var/livepatches as lib_t for ULP on micro (bsc#1228879)
  * Allow dirsrv-snmp map dirsv_tmpfs_t files
  * Label /usr/lib/node_modules_22/npm/bin with bin_t
  * Add policy for /usr/libexec/samba/samba-bgqd
  * Allow gnome-remote-desktop watch /etc directory
  * Allow rpcd read network sysctls
  * Allow journalctl connect to systemd-userdbd over a unix socket
  * Allow some confined users send to lldpad over a unix dgram socket
  * Allow lldpad send to unconfined_t over a unix dgram socket
  * Allow lldpd connect to systemd-machined over a unix socket
  * Confine the ktls service
  * Allow dirsrv read network sysctls
  * Label /run/sssd with sssd_var_run_t
  * Label /etc/sysctl.d and /run/sysctl.d with system_conf_t
  * Allow unconfined_t execute kmod in the kmod domain
  * Allow confined users r/w to screen unix stream socket
  * Label /root/.screenrc and /root/.tmux.conf with screen_home_t
  * Allow virtqemud read virtd_t files
  * Allow ping_t read network sysctls
  * Allow systemd-homework connect to init over a unix socket
  * Fix systemd-homed blobs directory permissions
  * Allow virtqemud read sgx_vepc devices
  * Allow lldpad create and use netlink_generic_socket
  * Allow snapperd to execute systemctl (bsc#1231489)
  * rsync: add rsync_exec_commands boolean and enable it by default (bsc#1231494)
  * Allow slpd to create TCPDIAG netlink socket (bsc#1231491)
  * Allow slpd to use sys_chroot (bsc#1231491)
  * Allow openvswitch-ipsec use strongswan (bsc#1231493)
  * Allow systemd-homework write to init pid socket
  * Allow init create /var/cache/systemd/home
  * Confine the pcm service
  * Allow login_userdomain read thumb tmp files
  * Update power-profiles-daemon policy
  * Fix the /etc/mdevctl\.d(/.*)? regexp
  * Grant rhsmcertd chown capability & userdb access
  * Allow iio-sensor-proxy the bpf capability
  * Allow systemd-machined the kill user-namespace capability
  * Remove the fail2ban module sources
  * Remove the linuxptp module sources
  * Remove legacy rules for slrnpull
  * Remove the aiccu module sources
  * Remove the bcfg2 module sources
  * Remove the amtu module sources
  * Remove the rhev module sources
  * Remove all file context entries for /bin and /lib
  * Allow ptp4l the sys_admin capability
  * Confine power-profiles-daemon
  * Label /var/cache/systemd/home with systemd_homed_cache_t
  * Allow login_userdomain connect to systemd-homed over a unix socket
  * Allow boothd connect to systemd-homed over a unix socket
  * Allow systemd-homed get attributes of a tmpfs filesystem
  * Allow abrt-dump-journal-core connect to systemd-homed over a unix socket
  * Allow aide connect to systemd-homed over a unix socket
  * Label /dev/hfi1_[0-9]+ devices
  * Remove the openct module sources
  * Remove the timidity module sources
  * Enable the slrn module
  * Remove i18n_input module sources
  * Enable the distcc module
  * Remove the ddcprobe module sources
  * Remove the timedatex module sources
  * Remove the djbdns module sources
  * Confine iio-sensor-proxy
  * Allow staff user nlmsg_write
  * Update policy for xdm with confined users
  * Allow virtnodedev watch mdevctl config dirs
  * Allow ssh watch home config dirs
  * Allow ssh map home configs files
  * Allow ssh read network sysctls
  * Allow chronyc sendto to chronyd-restricted
  * Allow cups sys_ptrace capability in the user namespace
  * Label auutyast binaries correctly
  * Allow snapperd to manage unlabeled_t files (bsc#1230966)
  * Add policy for systemd-homed
  * Revert "Allow virtstoraged to manage images (bsc#1228742)"
  * Remove fc entry for /usr/bin/pump
  * Label /usr/bin/noping and /usr/bin/oping with ping_exec_t
  * Allow accountsd read gnome-initial-setup tmp files
  * Allow xdm write to gnome-initial-setup fifo files
  * Allow rngd read and write generic usb devices
  * Allow qatlib search the content of the kernel debugging filesystem
  * Allow qatlib connect to systemd-machined over a unix socket
  * mls/modules.conf - fix typo
  * Use dist/targeted/modules.conf in build workflow
  * Fix default and dist config files
  * Allow unprivileged user watch /run/systemd
  * CI: update to actions/checkout@v4
  * Allow boothd connect to kernel over a unix socket
  * Clean up and sync securetty_types
  * Bring config files from dist-git into the source repo
  * Confine gnome-remote-desktop
  * Allow systemd_ibft_rule_generator_t to create udev_rules_t dirs (bsc#1230011)
  * Allow virtstoraged execute mount programs in the mount domain
  * Make mdevctl_conf_t member of the file_type attribute
  * Allow systemd_udev_trigger_generator_t list and read sysctls (bsc#1230315)
  * Initial policy for udev-trigger-generator (bsc#1230315)
  * Allow init_t mount syslog socket (bsc#1230134)
  * Allow init_t create syslog files (bsc#1230134)
  * Introduce initial policy for btrfs-soft-reboot-generator (bsc#1230134)
  * Label /etc/mdevctl.d with mdevctl_conf_t
  * Sync users with Fedora targeted users
  * Update policy for rpc-virtstorage
  * Allow virtstoraged get attributes of configfs dirs
  * Fix SELinux policy for sandbox X server to fix 'sandbox -X' command
  * Update bootupd policy when ESP is not mounted
  * Allow thumb_t map dri devices
  * Allow samba use the io_uring API
  * Allow the sysadm user use the secretmem API
  * Allow nut-upsmon read systemd-logind session files
  * Allow sysadm_t to create PF_KEY sockets
  * Update bootupd policy for the removing-state-file test
  * Allow xen to use qemu as dom0 disk backend (bsc#1228540)
  * Label /var/lib/xen/xenstore as xenstored_var_lib_t (bsc#1228540)
  * Allow coreos-installer-generator manage mdadm_conf_t files
  * Allow virtstoraged to manage images (bsc#1228742)
  * Allow virtstoraged_t domtrans to udev (bsc#1228742)
  * Allow setsebool_t relabel selinux data files
  * Allow virtqemud relabelfrom virtqemud_var_run_t dirs
  * Use better escape method for "interface"
  * Allow init and systemd-logind to inherit fds from sshd
  * Allow systemd-ssh-generator read sysctl files
  * Sync modules.conf with Fedora targeted modules
  * Allow systemd-ssh-generator to load net-pf-40 (bsc#1229766)
  * Allow virtqemud relabel user tmp files and socket files
  * Add missing sys_chroot capability to groupadd policy
  * Label /run/libvirt/qemu/channel with virtqemud_var_run_t
  * Allow rasdaemon write access to sysfs (bsc#1229587)
  * Allow xl to access hypercall interfaces to xen hypervisor (bsc#1228540)
  * Initial policy for syslog-ng (bsc#1229153)
  * Allow virtqemud relabelfrom also for file and sock_file
  * Add virt_create_log() and virt_write_log() interfaces
  * allow sshd_t and sshd_net_t access to ssh vsockets (bsc#1228831)
* Mon Dec 16 2024 cathy.hu@suse.com
- Update to version 20240604+git390.e897b9b3:
  * Allow vhostmd_t list virtqemud pid dirs (bsc#1230961)
* Wed Dec 11 2024 cathy.hu@suse.com
- Update to version 20240604+git388.baa001c6:
  * Label /run/libvirt/qemu/channel with virtqemud_var_run_t (bsc#1230961)
* Fri Nov 29 2024 jsegitz@suse.com
- Update macros.selinux-policy to trigger a full relabel on transactional
  systems upon module installation. This is rather expensive and will
  hopefully be replaced by a more fine grained solution later on (bsc#1232753)
* Tue Nov  5 2024 cathy.hu@suse.com
- Update to version 20240604+git386.c88be3c5:
  * Allow virt_dbus_t to connect to virtd_t over unix_stream_socket (bsc#1232655)
* Thu Oct 31 2024 cathy.hu@suse.com
- Update to version 20240604+git384.710b0da6:
  * Label /var/livepatches as lib_t for ULP on micro (bsc#1228879)
* Wed Sep 25 2024 cathy.hu@suse.com
- Update to version 20240604+git382.24f674cf:
  * Allow snapperd to manage unlabeled_t files (bsc#1230966)
* Tue Sep 24 2024 cathy.hu@suse.com
- Fix macros.selinux-policy (bsc#1230897)
  - %%selinux_relabel_post should not relabel files in
    transactional systems in %%post as the policy is not loaded
    into the kernel directly after install, instead the relabelling
    will happen on the next boot
* Thu Sep 12 2024 cathy.hu@suse.com
- Update to version 20240604+git380.95302f48:
  * Allow systemd_ibft_rule_generator_t to create udev_rules_t dirs (bsc#1230011)
  * Allow systemd_udev_trigger_generator_t list and read sysctls (bsc#1230315)
  * Initial policy for udev-trigger-generator (bsc#1230315)
* Wed Sep  4 2024 cathy.hu@suse.com
- Fix macros.selinux-policy (bsc#1229132)
  - %%selinux_modules_install and %%selinux_modules_uninstall will
    now only execute load_policy if $TRANSACTIONAL_UPDATE is not set
    (aka only if they are not in a transactional system)
  - $TRANSACTIONAL_UPDATE is set here:
    https://github.com/openSUSE/transactional-update/blob/bd524d3ddfcd9aeebb7b90d3e0e8eed09b796a86/lib/Transaction.cpp#L428
* Thu Aug 15 2024 cathy.hu@suse.com
- Update to version 20240604+git376.0406315d:
  * Dontaudit dac_override of fstab generator (bsc#1229127)
  * Update libvirt policy
  * Add port 80/udp and 443/udp to http_port_t definition
  * Additional updates stalld policy for bpf usage
  * Label systemd-pcrextend and systemd-pcrlock properly
  * Label /run/udev/rules.d as udev_rules_t
  * Provide type for sysstat lock files (bsc#1228247)
  * Allow coreos_installer_t work with partitions
  * Revert "Allow coreos-installer-generator work with partitions"
  * Add policy for systemd-pcrextend
  * Update policy for systemd-getty-generator
  * Allow snapper to delete unlabeled_t files (bsc#1228889)
  * Allow ip command write to ipsec's logs
  * Allow virt_driver_domain read virtd-lxc files in /proc
  * Revert "Allow svirt read virtqemud fifo files"
  * Update virtqemud policy for libguestfs usage
  * Allow virtproxyd create and use its private tmp files
  * Allow virtproxyd read network state
  * Allow virt_driver_domain create and use log files in /var/log (bsc#1227483)
  * Allow samba-dcerpcd work with ctdb cluster
  * Allow NetworkManager_dispatcher_t send SIGKILL to plugins
  * Allow setroubleshootd execute sendmail with a domain transition
  * Allow key.dns_resolve set attributes on the kernel key ring
  * Update qatlib policy for v24.02 with new features
  * Label /var/lib/systemd/sleep with systemd_sleep_var_lib_t
  * Allow tlp status power services
  * Allow virtqemud domain transition on passt execution
  * Allow virt_driver_domain connect to systemd-userdbd over a unix socket
  * Allow boothd connect to systemd-userdbd over a unix socket
  * Update policy for awstats scripts
  * Allow bitlbee execute generic programs in system bin directories
  * Allow login_userdomain read aliases file
  * Allow login_userdomain read ipsec config files
  * Allow login_userdomain read all pid files
  * Allow rsyslog read systemd-logind session files
  * Allow libvirt-dbus stream connect to virtlxcd
  * Use new kanidm interfaces
  * Initial module for kanidm
  * Update bootupd policy
  * Allow rhsmcertd read/write access to /dev/papr-sysparm
  * Label /dev/papr-sysparm and /dev/papr-vpd
  * Allow abrt-dump-journal-core connect to winbindd
  * Allow systemd-hostnamed shut down nscd
  * Allow systemd-pstore send a message to syslogd over a unix domain
  * Allow postfix_domain map postfix_etc_t files
  * Allow microcode create /sys/devices/system/cpu/microcode/reload
  * Allow rhsmcertd read, write, and map ica tmpfs files
  * Support SGX devices
  * Allow initrc_t transition to passwd_t
  * Update fstab and cryptsetup generators policy
  * Allow xdm_t read and write the dma device
  * Update stalld policy for bpf usage
  * Allow systemd_gpt_generator to getattr on DOS directories
  * Make cgroup_memory_pressure_t a part of the file_type attribute
  * Allow ssh_t to change role to system_r
  * Update policy for coreos generators
  * Allow init_t nnp domain transition to firewalld_t
  * Label /run/modprobe.d with modules_conf_t
  * Allow virtnodedevd run udev with a domain transition
  * Allow virtnodedev_t create and use virtnodedev_lock_t
  * Allow virtstoraged manage files with virt_content_t type
  * Allow virtqemud unmount a filesystem with extended attributes
  * Allow svirt_t connect to unconfined_t over a unix domain socket
  * Update afterburn file transition policy
  * Allow systemd_generator read attributes of all filesystems
  * Allow fstab-generator read and write cryptsetup-generator unit file
  * Allow cryptsetup-generator read and write fstab-generator unit file
  * Allow systemd_generator map files in /etc
  * Allow systemd_generator read init's process state
  * Allow coreos-installer-generator read sssd public files
  * Allow coreos-installer-generator work with partitions
  * Label /etc/mdadm.conf.d with mdadm_conf_t
  * Confine coreos generators
  * Label /run/metadata with afterburn_runtime_t
  * Allow afterburn list ssh home directory
  * Label samba certificates with samba_cert_t
  * Label /run/coreos-installer-reboot with coreos_installer_var_run_t
  * Allow virtqemud read virt-dbus process state
  * Allow staff user dbus chat with virt-dbus
  * Allow staff use watch /run/systemd
  * Allow systemd_generator to write kmsg
  * Allow virtqemud connect to sanlock over a unix stream socket
  * Allow virtqemud relabel virt_var_run_t directories
  * Allow svirt_tcg_t read vm sysctls
  * Allow virtnodedevd connect to systemd-userdbd over a unix socket
  * Allow svirt read virtqemud fifo files
  * Allow svirt attach_queue to a virtqemud tun_socket
  * Allow virtqemud run ssh client with a transition
  * Allow virt_dbus_t connect to virtqemud_t over a unix stream socket
  * Update keyutils policy
  * Allow sshd_keygen_t connect to userdbd over a unix stream socket
  * Allow postfix-smtpd read mysql config files
  * Allow locate stream connect to systemd-userdbd
  * Allow the staff user use wireshark
  * Allow updatedb connect to userdbd over a unix stream socket
  * Allow gpg_t set attributes of public-keys.d
  * Allow gpg_t get attributes of login_userdomain stream
  * Allow systemd_getty_generator_t read /proc/1/environ
  * Allow systemd_getty_generator_t to read and write to tty_device_t
  * Drop publicfile module
  * Remove permissive domain for systemd_nsresourced_t
  * Change fs_dontaudit_write_cgroup_files() to apply to cgroup_t
  * Label /usr/bin/samba-gpupdate with samba_gpupdate_exec_t
  * Allow to create and delete socket files created by rhsm.service
  * Allow virtnetworkd exec shell when virt_hooks_unconfined is on
  * Allow unconfined_service_t transition to passwd_t
  * Support /var is empty
  * Allow abrt-dump-journal read all non_security socket files
  * Allow timemaster write to sysfs files
  * Dontaudit domain write cgroup files
  * Label /usr/lib/node_modules/npm/bin with bin_t
  * Allow ip the setexec permission
  * Allow systemd-networkd write files in /var/lib/systemd/network
  * Fix typo in systemd_nsresourced_prog_run_bpf()
* Fri Aug  9 2024 cathy.hu@suse.com
- Update to version 20240604+git249.ce3c66e6:
  * Provide type for sysstat lock files (bsc#1228247)
  * Label /run/udev/rules.d as udev_rules_t
  * Allow snapper to delete unlabeled_t files (bsc#1228889)
* Mon Aug  5 2024 cathy.hu@suse.com
- Update to version 20240604+git244.3664e356:
  * Dontaudit search of snapper grub plugin to nscd socket (bsc#1228745)
  * Fix labels for bind/named
  * Initial policy for ibft-rule-generator (bsc#1228402)
  * Initial policy for systemd-status-mail (bsc#1228402)
  * Label /usr/libexec/netconfig/ppp/ip-up pppd_initrc_exec_t (bsc#1228385)
  * Allow pppd to manage sysnet directories (bsc#1228385)
  * Allow snapper grub plugin to manage unlabeled_t and read link files
* Fri Jul 26 2024 cathy.hu@suse.com
- Enable sap module
- Add equivalency in file_contexts.subs_dist
  * /bin /usr/bin
  * /sbin /usr/bin
  * /usr/sbin /usr/bin
  * /var/run /run
  * /var/lock /run/lock
- Move to %%posttrans to ensure selinux-policy got updated before
  the commands run (bsc#1221720)
- Remove "Reference" from the package description. It's not the
  reference policy, but the Fedora branch of the policy
- Update to version 20240604+git230.eb718617:
  * Initial policy for grub2 snapper plugin (bsc#1228205)
  * Set microos autorelabel script to systemd_autorelabel_generator_t
  * Allow systemd_generator to write kmsg
  * Initial policy for systemd growpart-generator (bsc#1226824)
  * Allow systemd_getty_generator_t read /proc/1/environ
  * Allow systemd_getty_generator_t to read and write to tty_device_t (bsc#1226888)
  * Change fc in rebootmgr module for /sbin -> /usr/bin
  * Change fc in rpm module for /sbin -> /usr/bin
  * Change fc in rsync module for /sbin -> /usr/bin
  * Change fc in wicked module for /sbin -> /usr/bin
  * Allow manage dosfs_t files to snapperd
  * Confine libvirt-dbus
  * Allow virtqemud the kill capability in user namespace
  * Allow rshim get options of the netlink class for KOBJECT_UEVENT family
  * Allow dhcpcd the kill capability
  * Allow systemd-networkd list /var/lib/systemd/network
  * Allow sysadm_t run systemd-nsresourced bpf programs
  * Update policy for systemd generators interactions
  * Allow create memory.pressure files with cgroup_memory_pressure_t
  * Add support for libvirt hooks
  * Allow certmonger read and write tpm devices
  * Allow all domains to connect to systemd-nsresourced over a unix socket
  * Allow systemd-machined read the vsock device
  * Update policy for systemd generators
  * Allow ptp4l_t request that the kernel load a kernel module
  * Allow sbd to trace processes in user namespace
  * Allow request-key execute scripts
  * Update policy for haproxyd
  * Add auth_rw_wtmpdb_login_records to domains using auth_manage_login_records
  * Add auth_rw_wtmpdb_login_records to modules
  * Allow xdm_t to read-write to wtmpdb (bsc#1225984)
  * Introduce types for wtmpdb and rw interface
  * Introduce wtmp_file_type attribute
  * Update policy for systemd-nsresourced
  * Correct sbin-related file context entries
  * Allow login_userdomain execute systemd-tmpfiles in the caller domain
  * Allow virt_driver_domain read files labeled unconfined_t
  * Allow virt_driver_domain dbus chat with policykit
  * Allow virtqemud manage nfs files when virt_use_nfs boolean is on
  * Add rules for interactions between generators
  * Label memory.pressure files with cgroup_memory_pressure_t
  * Revert "Allow some systemd services write to cgroup files"
  * Revert "Add policy for wtmpdb (bsc#1210717)"
  * Allow gnome control center to set autologin (bsc#1222978)
  * Update policy for systemd-nsresourced
  * Label /usr/bin/ntfsck with fsadm_exec_t
  * Allow systemd_fstab_generator_t read tmpfs files
  * Update policy for systemd-nsresourced
  * Dontaudit xdm_t to getattr on root_t (bsc#1223145)
  * Alias /usr/sbin to /usr/bin and change all /usr/sbin paths to /usr/bin
  * Remove a few lines duplicated between {dkim,milter}.fc
  * Alias /bin → /usr/bin and remove redundant paths
  * Drop duplicate line for /usr/sbin/unix_chkpwd
  * Drop duplicate paths for /usr/sbin
  * Allow systemd_fstab_generator_t read tmpfs files (bsc#1223599)
  * Update systemd-generator policy
  * Remove permissive domain for bootupd_t
  * Remove permissive domain for coreos_installer_t
  * Remove permissive domain for afterburn_t
  * Add the sap module to modules.conf
  * Move unconfined_domain(sap_unconfined_t) to an optional block
  * Create the sap module
  * Allow systemd-coredumpd sys_admin and sys_resource capabilities
  * Allow systemd-coredump read nsfs files
  * Allow generators auto file transition only for plain files
  * Allow systemd-hwdb write to the kernel messages device
  * Escape "interface" as a file name in a virt filetrans pattern
  * Allow gnome-software work for login_userdomain
  * Allow systemd-machined manage runtime sockets
  * Revert "Allow systemd-machined manage runtime sockets"
  * Allow postfix_domain connect to postgresql over a unix socket
  * Dontaudit systemd-coredump sys_admin capability
  * Allow all domains read and write z90crypt device
  * Allow tpm2 generator setfscreate
  * Allow systemd (PID 1) manage systemd conf files
  * Allow pulseaudio map its runtime files
  * Update policy for getty-generator
  * Allow systemd-hwdb send messages to kernel unix datagram sockets
  * Allow systemd-machined manage runtime sockets
  * Allow fstab-generator create unit file symlinks
  * Update policy for cryptsetup-generator
  * Update policy for fstab-generator
  * Allow virtqemud read vm sysctls
  * Allow collectd to trace processes in user namespace
  * Allow bootupd search efivarfs dirs
  * Add policy for systemd-mountfsd
  * Add policy for systemd-nsresourced
  * Update policy generators
  * Add policy for anaconda-generator
  * Update policy for fstab and gpt generators
  * Add policy for kdump-dep-generator
  * Add policy for a generic generator
  * Add policy for tpm2 generator
  * Add policy for ssh-generator
  * Add policy for second batch of generators
  * Update policy for systemd generators
  * ci: Adjust Cockpit test plans
  * Allow journald read systemd config files and directories
  * Allow systemd_domain read systemd_conf_t dirs
  * Fix bad Python regexp escapes
  * Allow fido services connect to postgres database
  * Revert "Update the README.md file with the c10s branch information"
  * Update the README.md file with the c10s branch information
  * Allow postfix smtpd map aliases file
  * Ensure dbus communication is allowed bidirectionally
  * Label systemd configuration files with systemd_conf_t
  * Label /run/systemd/machine with systemd_machined_var_run_t
  * Allow systemd-hostnamed read the vsock device
  * Allow sysadm execute dmidecode using sudo
  * Allow sudodomain list files in /var
  * Allow setroubleshootd get attributes of all sysctls
  * Allow various services read and write z90crypt device
  * Allow nfsidmap connect to systemd-homed
  * Allow sandbox_x_client_t dbus chat with accountsd
  * Allow system_cronjob_t dbus chat with avahi_t
  * Allow staff_t the io_uring sqpoll permission
  * Allow staff_t use the io_uring API
  * Add support for secretmem anon inode
  * Allow virtqemud read vfio devices
  * Allow virtqemud get attributes of a tmpfs filesystem
  * Allow svirt_t read vm sysctls
  * Allow virtqemud create and unlink files in /etc/libvirt/
  * Allow virtqemud get attributes of cifs files
  * Allow virtqemud get attributes of filesystems with extended attributes
  * Allow virtqemud get attributes of NFS filesystems
  * Allow virt_domain read and write usb devices conditionally
  * Allow virtstoraged use the io_uring API
  * Allow virtstoraged execute lvm programs in the lvm domain
  * Allow virtnodevd_t map /var/lib files
  * Allow svirt_tcg_t map svirt_image_t files
  * Allow abrt-dump-journal-core connect to systemd-homed
  * Allow abrt-dump-journal-core connect to systemd-machined
  * Allow sssd create and use io_uring
  * Allow selinux-relabel-generator create units dir
  * Allow dbus-broker read/write inherited user ttys
  * Define transitions for /run/libvirt/common and /run/libvirt/qemu
  * Allow systemd-sleep read raw disk data
  * Allow numad to trace processes in user namespace
  * Allow abrt-dump-journal-core connect to systemd-userdbd
  * Allow plymouthd read efivarfs files
  * Update the auth_dontaudit_read_passwd_file() interface
  * Label /dev/mmcblk0rpmb character device with removable_device_t
  * fix hibernate on btrfs swapfile (F40)
  * Allow nut to statfs()
  * Allow system dbusd service status systemd services
  * Allow systemd-timedated get the timemaster service status
  * Allow keyutils-dns-resolver connect to the system log service
  * Allow qemu-ga read vm sysctls
  * postfix: allow qmgr to delete mails in bounce/ directory
  * Remove duplicate in sysnetwork.fc
  * Rename /var/run/wicked* to /run/wicked*
  * Remove /var/run/rsyslog/additional-log-sockets.conf from logging.fc
  * policy: support pidfs
  * Confine selinux-autorelabel-generator.sh
  * Allow logwatch_mail_t read/write to init over a unix stream socket
  * Allow logwatch read logind sessions files
  * files_dontaudit_getattr_tmpfs_files allowed the access and didn't dontaudit it
  * files_dontaudit_mounton_modules_object allowed the access and didn't dontaudit it
  * Allow NetworkManager the sys_ptrace capability in user namespace
  * dontaudit execmem for modemmanager
  * Allow dhcpcd use unix_stream_socket
  * Allow dhcpc read /run/netns files
  * Update mmap_rw_file_perms to include the lock permission
  * Allow plymouthd log during shutdown
  * Add logging_watch_all_log_dirs() and logging_watch_all_log_files()
  * Allow journalctl_t read filesystem sysctls
  * Allow cgred_t to get attributes of cgroup filesystems
  * Allow wdmd read hardware state information
  * Allow wdmd list the contents of the sysfs directories
  * Allow linuxptp configure phc2sys and chronyd over a unix domain socket
  * Allow sulogin relabel tty1
  * Dontaudit sulogin the checkpoint_restore capability
  * Modify sudo_role_template() to allow getpgid
  * Allow userdomain get attributes of files on an nsfs filesystem
  * Allow opafm create NFS files and directories
  * Allow virtqemud create and unlink files in /etc/libvirt/
  * Allow virtqemud domain transition on swtpm execution
  * Add the swtpm.if interface file for interactions with other domains
  * Allow samba to have dac_override capability
  * systemd: allow sys_admin capability for systemd_notify_t
  * systemd: allow systemd_notify_t to send data to kernel_t datagram sockets
  * Allow thumb_t to watch and watch_reads mount_var_run_t
  * Allow krb5kdc_t map krb5kdc_principal_t files
  * Allow unprivileged confined user dbus chat with setroubleshoot
  * Allow login_userdomain map files in /var
  * Allow wireguard work with firewall-cmd
  * Differentiate between staff and sysadm when executing crontab with sudo
  * Add crontab_admin_domtrans interface
  * Allow abrt_t nnp domain transition to abrt_handle_event_t
  * Allow xdm_t to watch and watch_reads mount_var_run_t
  * Dontaudit subscription manager setfscreate and read file contexts
  * Don't audit crontab_domain write attempts to user home
  * Transition from sudodomains to crontab_t when executing crontab_exec_t
  * Add crontab_domtrans interface
  * Fix label of pseudoterminals created from sudodomain
  * Allow utempter_t use ptmx
  * Dontaudit rpmdb attempts to connect to sssd over a unix stream socket
  * Allow admin user read/write on fixed_disk_device_t
  * Only allow confined user domains to login locally without unconfined_login
  * Add userdom_spec_domtrans_confined_admin_users interface
  * Only allow admindomain to execute shell via ssh with ssh_sysadm_login
  * Add userdom_spec_domtrans_admin_users interface
  * Move ssh dyntrans to unconfined inside unconfined_login tunable policy
  * Update ssh_role_template() for user ssh-agent type
  * Allow init to inherit system DBus file descriptors
  * Allow init to inherit fds from syslogd
  * Allow any domain to inherit fds from rpm-ostree
  * Update afterburn policy
  * Allow init_t nnp domain transition to abrtd_t
  * Rename all /var/lock file context entries to /run/lock
  * Rename all /var/run file context entries to /run
- Update container-selinux to a68865582e123856c191fe0ecbbba9301758e591
* Tue Jul 16 2024 filippo.bonazzi@suse.com
- Fix systemd generator.early and generator.late file contexts (bsc#1227638)
* Tue Jun  4 2024 cathy.hu@suse.com
- Update to version 20240604+git0.ee0114f1:
  * allow firewalld access to /dev/random and write HW acceleration logs
* Thu Mar 21 2024 jsegitz@suse.com
- Update to version 20240321:
  * policy module for kiwi (bsc#1221109)
  * dontaudit execmem for modemmanager (bsc#1219363)
* Wed Mar 13 2024 cathy.hu@suse.com
- Update to version 20240313:
  * Assign alts_exec_t to files_type
* Fri Mar  8 2024 cathy.hu@suse.com
- Update to version 20240308:
  * Support /bin/alts in the policy (bsc#1217530)
  * Revert "Allow virtnetworkd_t to execute bin_t (bsc#1216903)"
* Wed Mar  6 2024 cathy.hu@suse.com
- Update to version 20240306:
  * Replace init domtrans rule for confined users to allow exec init
  * Update dbus_role_template() to allow user service status
  * Allow polkit status all systemd services
  * Allow setroubleshootd create and use inherited io_uring
  * Allow load_policy read and write generic ptys
* Mon Mar  4 2024 cathy.hu@suse.com
- Update to version 20240304:
  * Allow ssh-keygen to use the libica crypto module (bsc#1220373)
* Mon Feb  5 2024 cathy.hu@suse.com
- Update to version 20240205:
  * Allow gpg manage rpm cache
  * Allow login_userdomain name_bind to howl and xmsg udp ports
  * Allow rules for confined users logged in plasma
  * Label /dev/iommu with iommu_device_t
  * Remove duplicate file context entries in /run
  * Dontaudit getty and plymouth the checkpoint_restore capability (bsc#1220361)
  * Allow su domains write login records
  * Revert "Allow su domains write login records"
  * Allow login_userdomain delete session dbusd tmp socket files
  * Allow unix dgram sendto between exim processes
  * Allow su domains write login records
  * Allow smbd_t to watch user_home_dir_t if samba_enable_home_dirs is on
  * Allow chronyd-restricted read chronyd key files
  * Allow conntrackd_t to use bpf capability2
  * Allow systemd-networkd manage its runtime socket files
  * Allow init_t nnp domain transition to colord_t
  * Allow polkit status systemd services
  * nova: Fix duplicate declarations
  * Allow httpd work with PrivateTmp
  * Add interfaces for watching and reading ifconfig_var_run_t
  * Allow collectd read raw fixed disk device
  * Allow collectd read udev pid files
  * Set correct label on /etc/pki/pki-tomcat/kra
  * Allow systemd domains watch system dbus pid socket files
  * Allow certmonger read network sysctls
  * Allow mdadm list stratisd data directories
  * Allow syslog to run unconfined scripts conditionally
  * Allow syslogd_t nnp_transition to syslogd_unconfined_script_t
  * Allow qatlib set attributes of vfio device files
  * Allow systemd-sleep set attributes of efivarfs files
  * Allow samba-dcerpcd read public files
  * Allow spamd_update_t the sys_ptrace capability in user namespace
  * Allow bluetooth devices work with alsa
  * Allow alsa get attributes filesystems with extended attributes
  * Allow hypervkvp_t write access to NetworkManager_etc_rw_t
  * Add interface for write-only access to NetworkManager rw conf
  * Allow systemd-sleep send a message to syslog over a unix dgram socket
  * Allow init create and use netlink netfilter socket
  * Allow qatlib load kernel modules
  * Allow qatlib run lspci
  * Allow qatlib manage its private runtime socket files
  * Allow qatlib read/write vfio devices
  * Label /etc/redis.conf with redis_conf_t
  * Remove the lockdown-class rules from the policy
  * Allow init read all non-security socket files
  * Replace redundant dnsmasq pattern macros
  * Remove unneeded symlink perms in dnsmasq.if
  * Add additions to dnsmasq interface
  * Allow nvme_stas_t create and use netlink kobject uevent socket
  * Allow collectd connect to statsd port
  * Allow keepalived_t to use sys_ptrace of cap_userns
  * Allow dovecot_auth_t connect to postgresql using UNIX socket
  * Make named_zone_t and named_var_run_t a part of the mountpoint attribute
  * Allow sysadm execute traceroute in sysadm_t domain using sudo
  * Allow sysadm execute tcpdump in sysadm_t domain using sudo
  * Allow opafm search nfs directories
  * Add support for syslogd unconfined scripts
  * Allow gpsd use /dev/gnss devices
  * Allow gpg read rpm cache
  * Allow virtqemud additional permissions
  * Allow virtqemud manage its private lock files
  * Allow virtqemud use the io_uring api
  * Allow ddclient send e-mail notifications
  * Allow postfix_master_t map postfix data files
  * Allow init create and use vsock sockets
  * Allow thumb_t append to init unix domain stream sockets
  * Label /dev/vas with vas_device_t
  * Create interface selinux_watch_config and add it to SELinux users
  * Update cifs interfaces to include fs_search_auto_mountpoints()
  * Allow sudodomain read var auth files
  * Allow spamd_update_t read hardware state information
  * Allow virtnetworkd domain transition on tc command execution
  * Allow sendmail MTA connect to sendmail LDA
  * Allow auditd read all domains process state
  * Allow rsync read network sysctls
  * Add dhcpcd bpf capability to run bpf programs
  * Dontaudit systemd-hwdb dac_override capability
  * Allow systemd-sleep create efivarfs files
  * Allow map xserver_tmpfs_t files when xserver_clients_write_xshm is on
  * Allow graphical applications work in Wayland
  * Allow kdump work with PrivateTmp
  * Allow dovecot-auth work with PrivateTmp
  * Allow nfsd get attributes of all filesystems
  * Allow unconfined_domain_type use io_uring cmd on domain
  * ci: Only run Rawhide revdeps tests on the rawhide branch
  * Label /var/run/auditd.state as auditd_var_run_t
  * Allow fido-device-onboard (FDO) read the crack database
  * Allow ip an explicit domain transition to other domains
  * Label /usr/libexec/selinux/selinux-autorelabel with semanage_exec_t
  * Allow  winbind_rpcd_t processes access when samba_export_all_* is on
  * Enable NetworkManager and dhclient to use initramfs-configured DHCP connection
  * Allow ntp to bind and connect to ntske port.
* Tue Jan 16 2024 cathy.hu@suse.com
- Update to version 20240116:
  * Fix gitolite homedir paths (bsc#1218826)
* Tue Jan  9 2024 cathy.hu@suse.com
- Update to version 20240104:
  * Allow keepalived_t read+write kernel_t pipes (bsc#1216060)
  * allow rebootmgr to read the system state (bsc#1205931)
* Tue Nov 28 2023 cathy.hu@suse.com
- Trigger rebuild of the policy when pcre2 gets updated to avoid
  regex version mismatch errors (bsc#1216747).
* Fri Nov 24 2023 cathy.hu@suse.com
- Update to version 20231124:
  * Allow virtnetworkd_t to execute bin_t (bsc#1216903)
* Wed Nov 22 2023 cathy.hu@suse.com
- Add new modules that were missed in the last update to
  modules-mls-contrib.conf
* Wed Nov 22 2023 cathy.hu@suse.com
- Add new modules that were missed in the last update to
  modules-targeted-contrib.conf (bsc#1215405)
* Mon Oct 30 2023 cathy.hu@suse.com
- Update to version 20231030:
  * Allow system_mail_t manage exim spool files and dirs
  * Dontaudit keepalived setattr on keepalived_unconfined_script_exec_t
  * Label /run/pcsd.socket with cluster_var_run_t
  * ci: Run cockpit tests in PRs
  * Add map_read map_write to kernel_prog_run_bpf
  * Allow systemd-fstab-generator read all symlinks
  * Allow systemd-fstab-generator the dac_override capability
  * Allow rpcbind read network sysctls
  * Support using systemd containers
  * Allow sysadm_t to connect to iscsid using a unix domain stream socket
  * Add policy for coreos installer
  * Add policy for nvme-stas
  * Confine systemd fstab,sysv,rc-local
  * Label /etc/aliases.lmdb with etc_aliases_t
  * Create policy for afterburn
  * Make new virt drivers permissive
  * Split virt policy, introduce virt_supplementary module
  * Allow apcupsd cgi scripts read /sys
  * Allow kernel_t to manage and relabel all files
  * Add missing optional_policy() to files_relabel_all_files()
  * Allow named and ndc use the io_uring api
  * Deprecate common_anon_inode_perms usage
  * Improve default file context(None) of /var/lib/authselect/backups
  * Allow udev_t to search all directories with a filesystem type
  * Implement proper anon_inode support
  * Allow targetd write to the syslog pid sock_file
  * Add ipa_pki_retrieve_key_exec() interface
  * Allow kdumpctl_t to list all directories with a filesystem type
  * Allow udev additional permissions
  * Allow udev load kernel module
  * Allow sysadm_t to mmap modules_object_t files
  * Add the unconfined_read_files() and unconfined_list_dirs() interfaces
  * Set default file context of HOME_DIR/tmp/.* to <<none>>
  * Allow kernel_generic_helper_t to execute mount(1)
  * Allow sssd send SIGKILL to passkey_child running in ipa_otpd_t
  * Allow systemd-localed create Xserver config dirs
  * Allow sssd read symlinks in /etc/sssd
  * Label /dev/gnss[0-9] with gnss_device_t
  * Allow systemd-sleep read/write efivarfs variables
  * ci: Fix version number of packit generated srpms
  * Dontaudit rhsmcertd write memory device
  * Allow ssh_agent_type create a sockfile in /run/user/USERID
  * Set default file context of /var/lib/authselect/backups to <<none>>
  * Allow prosody read network sysctls
  * Allow cupsd_t to use bpf capability
  * Allow sssd domain transition on passkey_child execution conditionally
  * Allow login_userdomain watch lnk_files in /usr
  * Allow login_userdomain watch video4linux devices
  * Change systemd-network-generator transition to include class file
  * Revert "Change file transition for systemd-network-generator"
  * Allow nm-dispatcher winbind plugin read/write samba var files
  * Allow systemd-networkd write to cgroup files
  * Allow kdump create and use its memfd: objects (bsc#1219207)
  * Allow fedora-third-party get generic filesystem attributes
  * Allow sssd use usb devices conditionally
  * Update policy for qatlib
  * Allow ssh_agent_type manage generic cache home files
  * Change file transition for systemd-network-generator
  * Additional support for gnome-initial-setup
  * Update gnome-initial-setup policy for geoclue
  * Allow openconnect vpn open vhost net device
  * Allow cifs.upcall to connect to SSSD also through the /var/run socket
  * Grant cifs.upcall more required capabilities
  * Allow xenstored map xenfs files
  * Update policy for fdo
  * Allow keepalived watch var_run dirs
  * Allow svirt to rw /dev/udmabuf
  * Allow qatlib  to modify hardware state information.
  * Allow key.dns_resolve connect to avahi over a unix stream socket
  * Allow key.dns_resolve create and use unix datagram socket
  * Use quay.io as the container image source for CI
  * ci: Move srpm/rpm build to packit
  * .copr: Avoid subshell and changing directory
  * Allow gpsd, oddjob and oddjob_mkhomedir_t write user_tty_device_t chr_file
  * Label /usr/libexec/openssh/ssh-pkcs11-helper with ssh_agent_exec_t
  * Make insights_client_t an unconfined domain
  * Allow insights-client manage user temporary files
  * Allow insights-client create all rpm logs with a correct label
  * Allow insights-client manage generic logs
  * Allow cloud_init create dhclient var files and init_t manage net_conf_t
  * Allow insights-client read and write cluster tmpfs files
  * Allow ipsec read nsfs files
  * Make tuned work with mls policy
  * Remove nsplugin_role from mozilla.if
  * allow mon_procd_t self:cap_userns sys_ptrace
  * Allow pdns name_bind and name_connect all ports
  * Set the MLS range of fsdaemon_t to s0 - mls_systemhigh
  * ci: Move to actions/checkout@v3 version
  * .copr: Replace chown call with standard workflow safe.directory setting
  * .copr: Enable `set -u` for robustness
  * .copr: Simplify root directory variable
  * Allow rhsmcertd dbus chat with policykit
  * Allow polkitd execute pkla-check-authorization with nnp transition
  * Allow user_u and staff_u get attributes of non-security dirs
  * Allow unconfined user filetrans chrome_sandbox_home_t
  * Allow svnserve execute postdrop with a transition
  * Do not make postfix_postdrop_t type an MTA executable file
  * Allow samba-dcerpc service manage samba tmp files
  * Add use_nfs_home_dirs boolean for mozilla_plugin
  * Fix labeling for no-stub-resolv.conf
  * Revert "Allow winbind-rpcd use its private tmp files"
  * Allow upsmon execute upsmon via a helper script
  * Allow openconnect vpn read/write inherited vhost net device
  * Allow winbind-rpcd use its private tmp files
  * Update samba-dcerpc policy for printing
  * Allow gpsd,oddjob,oddjob_mkhomedir rw user domain pty
  * Allow nscd watch system db dirs
  * Allow qatlib to read sssd public files
  * Allow fedora-third-party read /sys and proc
  * Allow systemd-gpt-generator mount a tmpfs filesystem
  * Allow journald write to cgroup files
  * Allow rpc.mountd read network sysctls
  * Allow blueman read the contents of the sysfs filesystem
  * Allow logrotate_t to map generic files in /etc
  * Boolean: Allow virt_qemu_ga create ssh directory
  * Allow systemd-network-generator send system log messages
  * Dontaudit the execute permission on sock_file globally
  * Allow fsadm_t the file mounton permission
  * Allow named and ndc the io_uring sqpoll permission
  * Allow sssd io_uring sqpoll permission
  * Fix location for /run/nsd
  * Allow qemu-ga get fixed disk devices attributes
  * Update bitlbee policy
  * Label /usr/sbin/sos with sosreport_exec_t
  * Update policy for the sblim-sfcb service
  * Add the files_getattr_non_auth_dirs() interface
  * Fix the CI to work with DNF5
  * Make systemd_tmpfiles_t MLS trusted for lowering the level of files
  * Revert "Allow insights client map cache_home_t"
  * Allow nfsidmapd connect to systemd-machined over a unix socket
  * Allow snapperd connect to kernel over a unix domain stream socket
  * Allow virt_qemu_ga_t create .ssh dir with correct label
  * Allow targetd read network sysctls
  * Set the abrt_handle_event boolean to on
  * Permit kernel_t to change the user identity in object contexts
  * Allow insights client map cache_home_t
  * Label /usr/sbin/mariadbd with mysqld_exec_t
  * Allow httpd tcp connect to redis port conditionally
  * Label only /usr/sbin/ripd and ripngd with zebra_exec_t
  * Dontaudit aide the execmem permission
  * Remove permissive from fdo
  * Allow sa-update manage spamc home files
  * Allow sa-update connect to systemlog services
  * Label /usr/lib/systemd/system/mimedefang.service with antivirus_unit_file_t
  * Allow nsd_crond_t write nsd_var_run_t & connectto nsd_t
  * Allow bootupd search EFI directory
  * Change init_audit_control default value to true
  * Allow nfsidmapd connect to systemd-userdbd with a unix socket
  * Add the qatlib  module
  * Add the fdo module
  * Add the bootupd module
  * Set default ports for keylime policy
  * Create policy for qatlib
  * Add policy for FIDO Device Onboard
  * Add policy for bootupd
  * Add support for kafs-dns requested by keyutils
  * Allow insights-client execmem
  * Add support for chronyd-restricted
  * Add init_explicit_domain() interface
  * Allow fsadm_t to get attributes of cgroup filesystems
  * Add list_dir_perms to kerberos_read_keytab
  * Label /var/run/tmpfiles.d/static-nodes.conf with kmod_var_run_t
  * Allow sendmail manage its runtime files
* Thu Oct 12 2023 cathy.hu@suse.com
- Update to version 20231012:
  * Allow sssd_t watch permission to net_conf_t dirs (bsc#1216052)
  * Revert fix for bsc#1205770 since it causes a regression for bsc#1214887
* Wed Oct  4 2023 jsegitz@suse.com
- Use /var/adm/update-scripts in macros.selinux-policy. The rpm state
  directory doesn't exist on SUSE systems (bsc#1213593)
* Tue Sep 19 2023 jsegitz@suse.com
- Modified update.sh to require first parameter "full" to also
  update container-selinux. For maintenance updates you usually
  don't want it to be updated
* Fri Jul 28 2023 filippo.bonazzi@suse.com
- Update to version 20230728:
  * Allow kdump_t to manage symlinks under kdump_var_lib_t (bsc#1213721)
  * allow haveged to manage tmpfs directories (bsc#1213594)
* Thu Jun 22 2023 jsegitz@suse.com
- Update to version 20230622:
  * Allow keyutils_dns_resolver_exec_t be an entrypoint
  * Allow collectd_t read network state symlinks
  * Revert "Allow collectd_t read proc_net link files"
  * Allow nfsd_t to list exports_t dirs
  * Allow cupsd dbus chat with xdm
  * Allow haproxy read hardware state information
  * Label /dev/userfaultfd with userfaultfd_t
  * Allow blueman send general signals to unprivileged user domains
  * Allow dkim-milter domain transition to sendmail
* Tue Apr 25 2023 cathy.hu@suse.com
- Update to version 20230425:
  * Remove unneeded manage_dirs_pattern for lastlog_t (bsc#1210461)
  * Add policy for wtmpdb (bsc#1210717)
* Tue Apr 25 2023 cathy.hu@suse.com
- Update to version 20230425:
  * Add support for lastlog2 (bsc#1210461)
  * allow the chrony client to use unallocated ttys (bsc#1210672)
* Thu Apr 20 2023 jsegitz@suse.com
- Update to version 20230420:
  * libzypp creates temporary files in /var/adm/mount. Label it with
    rpm_var_cache_t to prevent wrong labels in /var/cache/zypp
  * only use rsync_exec_t for the rsync server, not for the client
    (bsc#1209890)
  * properly label sshd-gen-keys-start to ensure ssh host keys have proper
    labels after creation
  * Allow dovecot-deliver write to the main process runtime fifo files
  * Allow dmidecode write to cloud-init tmp files
  * Allow chronyd send a message to cloud-init over a datagram socket
  * Allow cloud-init domain transition to insights-client domain
  * Allow mongodb read filesystem sysctls
  * Allow mongodb read network sysctls
  * Allow accounts-daemon read generic systemd unit lnk files
  * Allow blueman watch generic device dirs
  * Allow nm-dispatcher tlp plugin create tlp dirs
  * Allow systemd-coredump mounton /usr
  * Allow rabbitmq to read network sysctls
  * Allow certmonger dbus chat with the cron system domain
  * Allow geoclue read network sysctls
  * Allow geoclue watch the /etc directory
  * Allow logwatch_mail_t read network sysctls
  * allow systemd_resolved_t to bind to all nodes (bsc#1200182)
  * Allow insights-client read all sysctls
  * Allow passt manage qemu pid sock files
  * Allow sssd read accountsd fifo files
  * Add support for the passt_t domain
  * Allow virtd_t and svirt_t work with passt
  * Add new interfaces in the virt module
  * Add passt interfaces defined conditionally
  * Allow tshark the setsched capability
  * Allow poweroff create connections to system dbus
  * Allow wg load kernel modules, search debugfs dir
  * Boolean: allow qemu-ga manage ssh home directory
  * Label smtpd with sendmail_exec_t
  * Label msmtp and msmtpd with sendmail_exec_t
  * Allow dovecot to map files in /var/spool/dovecot
  * Confine gnome-initial-setup
  * Allow qemu-guest-agent create and use vsock socket
  * Allow login_pgm setcap permission
  * Allow chronyc read network sysctls
  * Enhancement of the /usr/sbin/request-key helper policy
  * Fix opencryptoki file names in /dev/shm
  * Allow system_cronjob_t transition to rpm_script_t
  * Revert "Allow system_cronjob_t domtrans to rpm_script_t"
  * Add tunable to allow squid bind snmp port
  * Allow staff_t getattr init pid chr & blk files and read krb5
  * Allow firewalld to rw z90crypt device
  * Allow httpd work with tokens in /dev/shm
  * Allow svirt to map svirt_image_t char files
  * Allow sysadm_t run initrc_t script and sysadm_r role access
  * Allow insights-client manage fsadm pid files
  * Allowing snapper to create snapshots of /home/ subvolume/partition
  * Add boolean qemu-ga to run unconfined script
  * Label systemd-journald feature LogNamespace
  * Add none file context for polyinstantiated tmp dirs
  * Allow certmonger read the contents of the sysfs filesystem
  * Add journalctl the sys_resource capability
  * Allow nm-dispatcher plugins read generic files in /proc
* Tue Mar 28 2023 cathy.hu@suse.com
- Add debug-build.sh script to make debugging without committing easier
* Tue Mar 21 2023 jsegitz@suse.com
- Update to version 20230321:
  * make kernel_t unconfined again
* Thu Mar 16 2023 jsegitz@suse.com
- Update to version 20230316:
  * prevent labeling of overlayfs filesystems based on the /var/lib/overlay
    path
  * allow kernel_t to relabel etc_t files
  * allow kernel_t to relabel sysnet config files
  * allow kernel_t to relabel systemd hwdb etc files
  * add systemd_hwdb_relabel_etc_files to allow labeling of hwdb files
  * change sysnet_relabelto_net_conf and sysnet_relabelfrom_net_conf to apply
    to files and lnk_files. lnk_files are commonly used in SUSE to allow easy
    management of config files
  * add files_relabel_etc_files_basic and files_relabel_etc_lnk_files_basic
    interfaces to allow labeling on etc_t, not on the broader configfiles
    attribute
  * Allow systemd-timesyncd to bind to generic UDP ports (bsc#1207962). The
    watch permissions reported are already fixed in a current policy.
- Reinstate update.sh and remove container-selinux from the service.
  Having both repos in there causes issues and update.sh makes the update
  process easier in general. Updated README.Update
* Tue Mar  7 2023 jsegitz@suse.com
- Remove erroneous SUSE man page. Will not be created with the
  3.5 toolchain
* Tue Feb 14 2023 cathy.hu@suse.com
- Complete packaging rework: Move policy to git repository and
  only use tar_scm obs service to refresh from there:
  https://gitlab.suse.de/selinux/selinux-policy
  Please use `osc service manualrun` to update this OBS package to the
  newest git version.
  * Added README.Update describing how to update this package
  * Added _service file that pulls from selinux-policy and
    upstream container-selinux and tars them
  * Adapted selinux-policy.spec to build selinux-policy with
    container-selinux
  * Removed update.sh as no longer needed
  * Removed suse specific modules as they are now covered by git commits
  * packagekit.te packagekit.if packagekit.fc
  * rebootmgr.te rebootmgr.if rebootmgr.fc
  * rtorrent.te rtorrent.if rtorrent.fc
  * wicked.te wicked.if wicked.fc
  * Removed *.patch as they are now covered by git commits:
  * distro_suse_to_distro_redhat.patch
  * dontaudit_interface_kmod_tmpfs.patch
  * fix_accountsd.patch
  * fix_alsa.patch
  * fix_apache.patch
  * fix_auditd.patch
  * fix_authlogin.patch
  * fix_automount.patch
  * fix_bitlbee.patch
  * fix_chronyd.patch
  * fix_cloudform.patch
  * fix_colord.patch
  * fix_corecommand.patch
  * fix_cron.patch
  * fix_dbus.patch
  * fix_djbdns.patch
  * fix_dnsmasq.patch
  * fix_dovecot.patch
  * fix_entropyd.patch
  * fix_firewalld.patch
  * fix_fwupd.patch
  * fix_geoclue.patch
  * fix_hypervkvp.patch
  * fix_init.patch
  * fix_ipsec.patch
  * fix_iptables.patch
  * fix_irqbalance.patch
  * fix_java.patch
  * fix_kernel.patch
  * fix_kernel_sysctl.patch
  * fix_libraries.patch
  * fix_locallogin.patch
  * fix_logging.patch
  * fix_logrotate.patch
  * fix_mcelog.patch
  * fix_miscfiles.patch
  * fix_nagios.patch
  * fix_networkmanager.patch
  * fix_nis.patch
  * fix_nscd.patch
  * fix_ntp.patch
  * fix_openvpn.patch
  * fix_postfix.patch
  * fix_rpm.patch
  * fix_rtkit.patch
  * fix_screen.patch
  * fix_selinuxutil.patch
  * fix_sendmail.patch
  * fix_smartmon.patch
  * fix_snapper.patch
  * fix_sslh.patch
  * fix_sysnetwork.patch
  * fix_systemd.patch
  * fix_systemd_watch.patch
  * fix_thunderbird.patch
  * fix_unconfined.patch
  * fix_unconfineduser.patch
  * fix_unprivuser.patch
  * fix_userdomain.patch
  * fix_usermanage.patch
  * fix_wine.patch
  * fix_xserver.patch
  * sedoctool.patch
  * systemd_domain_dyntrans_type.patch
* Mon Feb  6 2023 jsegitz@suse.com
- Update to version 20230206. Refreshed:
  * fix_entropyd.patch
  * fix_networkmanager.patch
  * fix_systemd_watch.patch
  * fix_unconfineduser.patch
- Updated fix_kernel.patch to allow kernel_t access to xdm state. This is
  necessary as plymouth doesn't run in it's own domain in early boot
* Mon Jan 16 2023 jsegitz@suse.com
- Update to version 20230125. Refreshed:
  * distro_suse_to_distro_redhat.patch
  * fix_dnsmasq.patch
  * fix_init.patch
  * fix_ipsec.patch
  * fix_kernel_sysctl.patch
  * fix_logging.patch
  * fix_rpm.patch
  * fix_selinuxutil.patch
  * fix_systemd_watch.patch
  * fix_userdomain.patch
- More flexible lib(exec) matching in fix_fwupd.patch
- Removed sys_admin for systemd_gpt_generator_t in fix_systemd.patch
- Dropped fix_container.patch, is now upstream
- Added fix_entropyd.patch
  * Added new interface entropyd_semaphore_filetrans to properly transfer
    semaphore created during early boot. That doesn't work yet, so work
    around with next item
  * Allow reading tempfs files
- Added fix_kernel.patch. Added modutils_execute_kmod_tmpfs_files interace
  to allow kmod_tmpfs_t files to be executed. Necessary for firewalld
- Added fix_rtkit.patch to fix labeling of binary
- Modified fix_ntp.patch:
  * Proper labeling for start-ntpd
  * Fixed label rules for chroot path
  * Temporarily allow dac_override for ntpd_t (bsc#1207577)
  * Add interface ntp_manage_pid_files to allow management of pid
    files
- Updated fix_networkmanager.patch to allow managing ntp pid files
* Thu Jan 12 2023 jsegitz@suse.com
- Update fix_container.patch to allow privileged containers to use
  localectl (bsc#1207077)
* Wed Jan 11 2023 jsegitz@suse.com
- Add fix_container.patch to allow privileged containers to use
  timedatectl (bsc#1207054)
* Thu Dec 15 2022 cathy.hu@suse.com
- Added fix_ipsec.patch: Allow AF_ALG socket creation for strongswan
  (bnc#1206445)
* Wed Dec 14 2022 cathy.hu@suse.com
- Added policy for wicked scripts under /etc/sysconfig/network/scripts
  (bnc#1205770)
* Wed Dec 14 2022 jsegitz@suse.com
- Add fix_sendmail.patch
  * fix context of custom sendmail startup helper
  * fix context of /var/run/sendmail and add necessary rules to manage
    content in there
* Tue Dec 13 2022 jsegitz@suse.com
- Updated fix_networkmanager.patch to fixe labeling of nm-dispatcher and
  nm-priv-helper until the packaging is adjusted (bsc#1206355)
- Update fix_chronyd.patch to allow  sendto towards
  NetworkManager_dispatcher_custom_t. Added new interface
  networkmanager_dispatcher_custom_dgram_send for this (bsc#1206357)
- Update fix_dbus.patch to allow dbus to watch lib directories (bsc#1205895)
* Tue Dec  6 2022 jsegitz@suse.com
- Updated fix_networkmanager.patch to allow NetworkManager to watch
  net_conf_t (bsc#1206109)
* Wed Nov 30 2022 filippo.bonazzi@suse.com
- Add fix_irqbalance.patch: support netlink socket operations (bsc#1205434)
* Wed Nov 30 2022 filippo.bonazzi@suse.com
- Drop fix_irqbalance.patch: superseded by upstream
* Thu Nov 24 2022 cathy.hu@suse.com
- fix_sysnetwork.patch: firewalld uses /etc/sysconfig/network/ for
  network interface definition instead of /etc/sysconfig/network-scripts/,
  modified sysnetwork.fc to reflect that (bsc#1205580).
* Wed Oct 19 2022 jsegitz@suse.com
- Update to version 20221019. Refreshed:
  * distro_suse_to_distro_redhat.patch
  * fix_apache.patch
  * fix_chronyd.patch
  * fix_cron.patch
  * fix_init.patch
  * fix_kernel_sysctl.patch
  * fix_networkmanager.patch
  * fix_rpm.patch
  * fix_sysnetwork.patch
  * fix_systemd.patch
  * fix_systemd_watch.patch
  * fix_unconfined.patch
  * fix_unconfineduser.patch
  * fix_unprivuser.patch
  * fix_xserver.patch
- Dropped fix_cockpit.patch as this is now packaged with cockpit itself
- Remove the ipa module, freeip ships their own module
- Added fix_alsa.patch to allow reading of config files in home directories
- Extended fix_networkmanager.patch and fix_postfix.patch to account
  for SUSE systems
- Added dontaudit_interface_kmod_tmpfs.patch to prevent AVCs when startproc
  queries the running processes
- Updated fix_snapper.patch to allow snapper to talk to rpm via dbus
* Fri Sep 30 2022 jsegitz@suse.com
- Updated quilt couldn't unpack tarball. This will cause ongoing issues
  so drop the sed statement in the %%prep section and add
  distro_suse_to_distro_redhat.patch to add the necessary changes
  via a patch
* Thu Sep 29 2022 jsegitz@suse.com
- Update fix_networkmanager.patch to ensure NetworkManager chrony
  dispatcher is properly labled and update fix_chronyd.patch to ensure
  chrony helper script has proper label to be used by NetworkManager.
  Also allow NetworkManager_dispatcher_custom_t to query systemd status
  (bsc#1203824)
* Tue Sep 27 2022 filippo.bonazzi@suse.com
- Update fix_xserver.patch to add greetd support (bsc#1198559)
* Mon Sep 12 2022 jsegitz@suse.com
- Revamped rtorrent module
* Fri Aug 26 2022 kukuk@suse.com
- Move SUSE directory from manual page section to html docu
* Wed Jul 27 2022 cathy.hu@suse.com
- fix_networkmanager.patch: Allow NetworkManager_dispatcher_tlp_t
  and NetworkManager_dispatcher_custom_t to access nscd socket
  (bsc#1201741)
* Tue Jul 26 2022 zkubala@suse.com
- Add fix_cloudform.patch to fix cloud-init runcmd issue with snapper
  (bnc#1201015)
* Thu Jul 14 2022 jsegitz@suse.com
- Update to version 20220714. Refreshed:
  * fix_init.patch
  * fix_systemd_watch.patch
* Wed Jul 13 2022 jsegitz@suse.com
- Update fix_systemd.patch to add cap sys_admin and kernel_dgram_send for
  systemd_gpt_generator_t (bsc#1200911)
* Mon Jul 11 2022 jsegitz@suse.com
- postfix: Label PID files and some helpers correctly (bsc#1197242)
* Fri Jun 24 2022 jsegitz@suse.com
- Add fix_userdomain.patch to dontaudit UDP rpc ports (bsc#1193984)
* Fri Jun 24 2022 jsegitz@suse.com
- Update to version 20220624. Refreshed:
  * fix_init.patch
  * fix_kernel_sysctl.patch
  * fix_logging.patch
  * fix_networkmanager.patch
  * fix_unprivuser.patch
  Dropped fix_hadoop.patch, not necessary anymore
  * Updated fix_locallogin.patch to allow accesses for nss-systemd
  (bsc#1199630)
* Fri May 20 2022 jsegitz@suse.com
- Update to version 20220520 to pass stricter 3.4 toolchain checks
* Fri May 20 2022 jsegitz@suse.com
- Update to version 20220428. Refreshed:
  * fix_apache.patch
  * fix_hadoop.patch
  * fix_init.patch
  * fix_iptables.patch
  * fix_kernel_sysctl.patch
  * fix_networkmanager.patch
  * fix_systemd.patch
  * fix_systemd_watch.patch
  * fix_unprivuser.patch
  * fix_usermanage.patch
  * fix_wine.patch
* Thu May 19 2022 jsegitz@suse.com
- Add fix_dnsmasq.patch to fix problems with virtualization on Microos
  (bsc#1199518)
* Tue May  3 2022 jsegitz@suse.com
- Modified fix_init.patch to allow init to setup contrained environment
  for accountsservice. This needs a better, more general solution
  (bsc#1197610)
* Mon May  2 2022 jsegitz@suse.com
- Add systemd_domain_dyntrans_type.patch to allow systemd to dyntransition.
  This happens in certain boot conditions (bsc#1182500)
- Changed fix_unconfineduser.patch to not transition into ldconfig_t
  from unconfined_t (bsc#1197169)
* Thu Feb 17 2022 kkaempf@suse.com
- use %%license tag for COPYING file
* Thu Feb 10 2022 jsegitz@suse.com
- Updated fix_cron.patch. Adjust labeling for at (bsc#1195683)
* Wed Feb  9 2022 filippo.bonazzi@suse.com
- Fix bitlbee runtime directory (bsc#1193230)
  * add fix_bitlbee.patch
* Mon Jan 24 2022 jsegitz@suse.com
- Update to version 20220124. Refreshed:
  * fix_hadoop.patch
  * fix_init.patch
  * fix_kernel_sysctl.patch
  * fix_systemd.patch
  * fix_systemd_watch.patch
- Added fix_hypervkvp.patch to fix issues with hyperv labeling
  (bsc#1193987)
* Fri Jan 14 2022 jsegitz@suse.com
- Allow colord to use systemd hardenings (bsc#1194631)
* Thu Nov 11 2021 jsegitz@suse.com
- Update to version 20211111. Refreshed:
  * fix_dbus.patch
  * fix_systemd.patch
  * fix_authlogin.patch
  * fix_auditd.patch
  * fix_kernel_sysctl.patch
  * fix_networkmanager.patch
  * fix_chronyd.patch
  * fix_unconfineduser.patch
  * fix_unconfined.patch
  * fix_firewalld.patch
  * fix_init.patch
  * fix_xserver.patch
  * fix_logging.patch
  * fix_hadoop.patch
* Mon Oct 25 2021 meissner@suse.com
- fix_wine.patch: give Wine .dll same context as .so (bsc#1191976)
* Tue Sep 28 2021 ematsumiya@suse.com
- Fix auditd service start with systemd hardening directives (boo#1190918)
  * add fix_auditd.patch
* Thu Sep  2 2021 jsegitz@suse.com
- Modified fix_systemd.patch to allow systemd gpt generator access to
  udev files (bsc#1189280)
* Fri Aug 27 2021 ales.kedroutek@suse.com
- fix rebootmgr does not trigger the reboot properly (boo#1189878)
  * fix managing /etc/rebootmgr.conf
  * allow rebootmgr_t to cope with systemd and dbus messaging
* Thu Aug 26 2021 jsegitz@suse.com
- Properly label cockpit files
- Allow wicked to communicate with network manager on DBUS (bsc#1188331)
* Mon Aug 23 2021 ales.kedroutek@suse.com
- Added policy module for rebootmgr (jsc#SMO-28)
* Tue Aug 17 2021 lnussel@suse.de
- Allow systemd-sysctl to read kernel specific sysctl.conf
  (fix_kernel_sysctl.patch, boo#1184804)
* Tue Aug 10 2021 lnussel@suse.de
- Fix quoting in postInstall macro
* Fri Jul 16 2021 jsegitz@suse.com
- Update to version 20210716
- Remove interfaces for container module before building the package
  (bsc#1188184)
- Updated
  * fix_init.patch
  * fix_systemd_watch.patch
  to adapt to upstream changes
* Thu Jul 15 2021 gmbr3@opensuse.org
- Use tabrmd SELinux modules from tpm2.0-abrmd instead of storing
  here
* Tue Jul  6 2021 aplanas@suse.com
- Add tabrmd SELinux modules from upstream (bsc#1187925)
  https://github.com/tpm2-software/tpm2-abrmd/tree/master/selinux
- Automatic spec-cleaner to fix ordering and misaligned spaces
* Mon Jun 28 2021 jsegitz@suse.com
- Update to version 20210419
- Dropped fix_gift.patch, module was removed
- Updated wicked.te to removed dropped interface
- Refreshed:
  * fix_cockpit.patch
  * fix_hadoop.patch
  * fix_init.patch
  * fix_logging.patch
  * fix_logrotate.patch
  * fix_networkmanager.patch
  * fix_nscd.patch
  * fix_rpm.patch
  * fix_selinuxutil.patch
  * fix_systemd.patch
  * fix_systemd_watch.patch
  * fix_thunderbird.patch
  * fix_unconfined.patch
  * fix_unconfineduser.patch
  * fix_unprivuser.patch
  * fix_xserver.patch
* Tue May 18 2021 lnussel@suse.de
- allow systemd to watch /usr, /usr/lib, /etc, /etc/pki as we have path units
  that trigger on changes in those.
  Added fix_systemd_watch.patch
- own /usr/share/selinux/packages/$SELINUXTYPE/ and
  /var/lib/selinux/$SELINUXTYPE/active/modules/* to allow packages to install
  files there
* Wed Apr 28 2021 lnussel@suse.de
- allow cockpit socket to bind nodes (fix_cockpit.patch)
- use %%autosetup to get rid of endless patch lines
* Tue Apr 27 2021 jsegitz@suse.com
- Updated fix_networkmanager.patch to allow NetworkManager to watch
  its configuration directories
- Added fix_dovecot.patch to fix dovecot authentication (bsc#1182207)
* Mon Apr 26 2021 jsegitz@suse.com
- Added Recommends for selinux-autorelabel (bsc#1181837)
- Prevent libreoffice fonts from changing types on every relabel
  (bsc#1185265). Added fix_libraries.patch
* Fri Apr 23 2021 jsegitz@suse.com
- Transition unconfined users to ldconfig type (bsc#1183121).
  Extended fix_unconfineduser.patch
* Mon Apr 19 2021 jsegitz@suse.com
- Update to version 20210419
- Refreshed:
  * fix_dbus.patch
  * fix_hadoop.patch
  * fix_init.patch
  * fix_unprivuser.patch
* Fri Mar 12 2021 ales.kedroutek@suse.com
- Adjust fix_init.patch to allow systemd to do sd-listen on
  tcp socket [bsc#1183177]
* Tue Mar  9 2021 jsegitz@suse.com
- Update to version 20210309
- Refreshed
  * fix_systemd.patch
  * fix_selinuxutil.patch
  * fix_iptables.patch
  * fix_init.patch
  * fix_logging.patch
  * fix_nscd.patch
  * fix_hadoop.patch
  * fix_unconfineduser.patch
  * fix_chronyd.patch
  * fix_networkmanager.patch
  * fix_cron.patch
  * fix_usermanage.patch
  * fix_unprivuser.patch
  * fix_rpm.patch
- Ensure that /usr/etc is labeled according to /etc rules
* Tue Feb 23 2021 kukuk@suse.com
- Update to version 20210223
- Change name of tar file to a more common schema to allow
  parallel installation of several source versions
- Adjust fix_init.patch
* Mon Jan 11 2021 kukuk@suse.com
- Update to version 20210111
  - Drop fix_policykit.patch (integrated upstream)
  - Adjust fix_iptables.patch
  - update container policy
* Tue Nov 10 2020 jsegitz@suse.com
- Updated fix_corecommand.patch to set correct types for the OBS
  build tools
* Thu Oct 29 2020 kukuk@suse.com
- wicked.fc: add libexec directories
- Update to version 20201029
  - update container policy
* Fri Oct 16 2020 kukuk@suse.com
- Update to version 20201016
- Use python3 to build (fc_sort.c was replaced by fc_sort.py which
  uses python3)
- Drop SELINUX=disabled, "selinux=0" kernel commandline option has
  to be used instead. New default is "permissive" [bsc#1176923].
* Thu Sep 10 2020 jsegitz@suse.com
- Update to version 20200910. Refreshed
  * fix_authlogin.patch
  * fix_nagios.patch
  * fix_systemd.patch
  * fix_usermanage.patch
- Delete suse_specific.patch, moved content into fix_selinuxutil.patch
- Cleanup of booleans-* presets
  * Enabled
    user_rw_noexattrfile
    unconfined_chrome_sandbox_transition
    unconfined_mozilla_plugin_transition
    for the minimal policy
  * Disabled
    xserver_object_manager
    for the MLS policy
  * Disabled
    openvpn_enable_homedirs
    privoxy_connect_any
    selinuxuser_direct_dri_enabled
    selinuxuser_ping (aka user_ping)
    squid_connect_any
    telepathy_tcp_connect_generic_network_ports
    for the targeted policy
  Change your local config if you need them
- Build HTML version of manpages for the -devel package
* Thu Sep  3 2020 jsegitz@suse.com
- Drop BuildRequires for python, python-xml. It's not needed anymore
* Tue Sep  1 2020 jsegitz@suse.com
- Drop fix_dbus.patch_orig, was included by accident
- Drop segenxml_interpreter.patch, not used anymore
* Tue Aug 11 2020 kukuk@suse.com
- macros.selinux-policy: move rpm-state directory to /run and
  make sure it exists
* Wed Aug  5 2020 kukuk@suse.com
- Cleanup spec file and follow more closely Fedora
- Label /sys/kernel/uevent_helper with tmpfiles.d/selinux-policy.conf
- Move config to /etc/selinux/config and create during %%post install
  to be compatible with upstream and documentation.
- Add RPM macros for SELinux (macros.selinux-policy)
- Install booleans.subs_dist
- Remove unused macros
- Sync make/install macros with Fedora spec file
- Introduce sandbox sub-package
* Wed Jul 29 2020 kukuk@suse.com
- Add policycoreutils-devel as BuildRequires
* Fri Jul 17 2020 jsegitz@suse.com
- Update to version 20200717. Refreshed
  * fix_fwupd.patch
  * fix_hadoop.patch
  * fix_init.patch
  * fix_irqbalance.patch
  * fix_logrotate.patch
  * fix_nagios.patch
  * fix_networkmanager.patch
  * fix_postfix.patch
  * fix_sysnetwork.patch
  * fix_systemd.patch
  * fix_thunderbird.patch
  * fix_unconfined.patch
  * fix_unprivuser.patch
  * selinux-policy.spec
- Added update.sh to make updating easier
* Tue Jul 14 2020 jsegitz@suse.com
- Updated fix_unconfineduser.patch to allow unconfined_dbusd_t access
  to accountsd dbus
- New patch:
  * fix_nis.patch
- Updated patches:
  * fix_postfix.patch: Transition is done in distribution specific script
* Tue Jun  2 2020 jsegitz@suse.de
- Added module for wicked
- New patches:
  * fix_authlogin.patch
  * fix_screen.patch
  * fix_unprivuser.patch
  * fix_rpm.patch
  * fix_apache.patch
* Thu Mar 26 2020 jsegitz@suse.de
- Added module for rtorrent
- Enable snapper module in minimum policy to reduce issues on BTRFS
  Updated fix_snapper.patch to prevent relabling of snapshot
* Mon Mar  9 2020 jsegitz@suse.de
- New patches:
  * fix_accountsd.patch
  * fix_automount.patch
  * fix_colord.patch
  * fix_mcelog.patch
  * fix_sslh.patch
  * fix_nagios.patch
  * fix_openvpn.patch
  * fix_cron.patch
  * fix_usermanage.patch
  * fix_smartmon.patch
  * fix_geoclue.patch
  * suse_specific.patch
  Default systems should now work without selinuxuser_execmod
- Removed xdm_entrypoint_pam.patch, necessary change is in
  fix_unconfineduser.patch
- Enable SUSE specific settings again
* Wed Feb 19 2020 jsegitz@suse.de
- Update to version 20200219
  Refreshed fix_hadoop.patch
  Updated
  * fix_dbus.patch
  * fix_hadoop.patch
  * fix_nscd.patch
  * fix_xserver.patch
  Renamed postfix_paths.patch to fix_postfix.patch
  Added
  * fix_init.patch
  * fix_locallogin.patch
  * fix_policykit.patch
  * fix_iptables.patch
  * fix_irqbalance.patch
  * fix_ntp.patch
  * fix_fwupd.patch
  * fix_firewalld.patch
  * fix_logrotate.patch
  * fix_selinuxutil.patch
  * fix_corecommand.patch
  * fix_snapper.patch
  * fix_systemd.patch
  * fix_unconfined.patch
  * fix_unconfineduser.patch
  * fix_chronyd.patch
  * fix_networkmanager.patch
  * xdm_entrypoint_pam.patch
- Removed modules minimum_temp_fixes and targeted_temp_fixes
  from the corresponding policies
- Reduced default module list of minimum policy by removing
  apache inetd nis postfix mta modules
- Adding/removing necessary pam config automatically
- Minimum and targeted policy: Enable domain_can_mmap_files by default
- Targeted policy: Disable selinuxuser_execmem, selinuxuser_execmod and
  selinuxuser_execstack to have safe defaults
* Fri Aug  9 2019 jsegitz@suse.de
- Moved back to fedora policy (20190802)
- Removed spec file conditionals for old SELinux userland
- Removed config.tgz
- Removed patches:
  * label_sysconfig.selinux.patch
  * label_var_run_rsyslog.patch
  * suse_additions_obs.patch
  * suse_additions_sslh.patch
  * suse_modifications_apache.patch
  * suse_modifications_cron.patch
  * suse_modifications_getty.patch
  * suse_modifications_logging.patch
  * suse_modifications_ntp.patch
  * suse_modifications_usermanage.patch
  * suse_modifications_virt.patch
  * suse_modifications_xserver.patch
  * sysconfig_network_scripts.patch
  * segenxml_interpreter.patch
- Added patches:
  * fix_djbdns.patch
  * fix_dbus.patch
  * fix_gift.patch
  * fix_java.patch
  * fix_hadoop.patch
  * fix_thunderbird.patch
  * postfix_paths.patch
  * fix_nscd.patch
  * fix_sysnetwork.patch
  * fix_logging.patch
  * fix_xserver.patch
  * fix_miscfiles.patch
  to fix problems with the coresponding modules
- Added sedoctool.patch to prevent build failures
- This also adds three modules:
  * packagekit.(te|if|fc)
    Basic (currently permissive) module for packagekit
  * minimum_temp_fixes.(te|if|fc)
    and
  * targeted_temp_fixes.(te|if|fc)
    both are currently necessary to get the systems to boot in
    enforcing mode. Most of them obviosly stem from mislabeled
    files, so this needs to be worked through and then removed
    eventually
  Also selinuxuser_execstack, selinuxuser_execmod and
  domain_can_mmap_files need to be enabled. Especially the first
  two are bad and should be removed ASAP
* Thu Jul 11 2019 jsegitz@suse.com
- Update to refpolicy 20190609. New modules for stubby and several
  systemd updates, including initial support for systemd --user
  sessions.
  Refreshed
  * label_var_run_rsyslog.patch
  * suse_modifications_cron.patch
  * suse_modifications_logging.patch
  * suse_modifications_ntp.patch
  * suse_modifications_usermanage.patch
  * suse_modifications_xserver.patch
  * sysconfig_network_scripts.patch
* Mon Feb  4 2019 jsegitz@suse.com
- Update to refpolicy 20190201. New modules for chromium, hostapd,
  and sigrok and minor fixes for existing modules.
  Refreshed suse_modifications_usermanage.patch
* Wed Nov 28 2018 jsegitz@suse.com
- Change default state to disabled and disable SELinux after
  uninstallation of policy to prevent unbootable system
  (bsc#1108949, bsc#1109590)
* Tue Nov 27 2018 jsegitz@suse.com
- Use refpolicy 20180701 as a base
- Dropped patches
  * allow-local_login_t-read-shadow.patch
  * dont_use_xmllint_in_make_conf.patch
  * label_sysconfig.selinux-policy.patch
  * policy-rawhide-base.patch
  * policy-rawhide-contrib.patch
  * suse_modifications_authlogin.patch
  * suse_modifications_dbus.patch
  * suse_modifications_glusterfs.patch
  * suse_modifications_ipsec.patch
  * suse_modifications_passenger.patch
  * suse_modifications_policykit.patch
  * suse_modifications_postfix.patch
  * suse_modifications_rtkit.patch
  * suse_modifications_selinuxutil.patch
  * suse_modifications_ssh.patch
  * suse_modifications_staff.patch
  * suse_modifications_stapserver.patch
  * suse_modifications_systemd.patch
  * suse_modifications_unconfined.patch
  * suse_modifications_unconfineduser.patch
  * suse_modifications_unprivuser.patch
  * systemd-tmpfiles.patch
  * type_transition_contrib.patch
  * type_transition_file_class.patch
  * useradd-netlink_selinux_socket.patch
  * xconsole.patch
  Rebased the other patches to apply to refpolicy
- Added segenxml_interpreter.patch to not use env in shebang
- Added rpmlintrc to surpress duplicate file warnings
* Mon Mar 26 2018 rgoldwyn@suse.com
- Add overlayfs as xattr capable (bsc#1073741)
  * add-overlayfs-as-xattr-capable.patch
* Tue Dec 12 2017 jsegitz@suse.com
- Added
  * suse_modifications_glusterfs.patch
  * suse_modifications_passenger.patch
  * suse_modifications_stapserver.patch
  to modify module name to make the current tools happy
* Wed Nov 29 2017 rbrown@suse.com
- Repair erroneous changes introduced with %%_fillupdir macro
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Wed Mar 15 2017 mwilck@suse.com
- POLCYVER depends both on the libsemanage/policycoreutils version
  and the kernel. The former is more important for us, kernel seems
  to have all necessary features in Leap 42.1 already.
- Replaced = runtime dependencies on checkpolicy/policycoreutils
  with "=". 2.5 policy is not supposed to work with 2.3 tools,
  The runtime policy tools need to be same the policy was built with.
* Wed Mar 15 2017 mwilck@suse.com
- Changes required by policycoreutils update to 2.5
  * lots of spec file content needs to be conditional on
    policycoreutils version.
- Specific policycoreutils 2.5 related changes:
  * modules moved from /etc/selinux to /var/lib/selinux
  (https://github.com/SELinuxProject/selinux/wiki/Policy-Store-Migration)
  * module path now includes includes priority. Users override default
  policies by setting higher priority. Thus installed policy modules can be
  fully verified by RPM.
  * Installed modules have a different format and path.
  Raw bzip2 doesn't suffice to create them any more, but we can process them
  all in a single semodule -i command.
- Policy version depends on kernel / distro version
  * do not touch policy.<version>, rather fail if it's not created
- Enabled building mls policy for Leap (not for SLES)
- Other
  * Bug: "sandbox.disabled" should be "sandbox.pp.disabled" for old policycoreutils
  * Bug: (minimum) additional modules that need to be activated: postfix
  (required by apache), plymouthd (required by getty)
  * Cleanup: /etc -> %%{sysconfdir} etc.
* Thu Aug 13 2015 jsegitz@novell.com
- fixed missing role assignment in cron_unconfined_role
* Tue Aug 11 2015 jsegitz@novell.com
- Updated suse_modifications_ipsec.patch, removed dontaudits for
  ipsec_mgmt_t and granted matching permissions
* Wed Aug  5 2015 jsegitz@novell.com
- Added suse_modifications_ipsec.patch to grant additional privileges
  to ipsec_mgmt_t
* Tue Jul 21 2015 jsegitz@novell.com
- Minor changes for CC evaluation. Allow reading of /dev/random
  and ipc_lock for dbus and dhcp
* Wed Jun 24 2015 jsegitz@novell.com
- Transition from unconfined user to cron admin type
- Allow systemd_timedated_t to talk to unconfined dbus for minimal
  policy (bsc#932826)
- Allow hostnamectl to set the hostname (bsc#933764)
* Wed May 20 2015 jsegitz@novell.com
- Removed ability of staff_t and user_t to use svirt. Will reenable
  this later on with a policy upgrade
  Added suse_modifications_staff.patch
* Wed Feb 25 2015 jsegitz@novell.com
- Added dont_use_xmllint_in_make_conf.patch to remove xmllint usage
  in make conf. This currently breaks manual builds.
- Added BuildRequires for libxml2-tools to enable xmllint checks
  once the issue mentioned above is solved
* Thu Jan 29 2015 jsegitz@novell.com
- adjusted suse_modifications_ntp to match SUSE chroot paths
* Wed Jan 28 2015 jsegitz@novell.com
- Added
  * suse_additions_obs.patch to allow local builds by OBS
  * suse_additions_sslh.patch to confine sslh
- Added suse_modifications_cron.patch to adjust crontabs contexts
- Modified suse_modifications_postfix.patch to match SUSE paths
- Modified suse_modifications_ssh.patch to bring boolean
  sshd_forward_ports back
- Modified
  * suse_modifications_dbus.patch
  * suse_modifications_unprivuser.patch
  * suse_modifications_xserver.patch
  to allow users to be confined
- Added
  * suse_modifications_apache.patch
  * suse_modifications_ntp.patch
  and modified
  * suse_modifications_xserver.patch
  to fix labels on startup scripts used by systemd
- Removed unused and incorrect interface dev_create_all_dev_nodes
  from systemd-tmpfiles.patch
- Removed BuildRequire for selinux-policy-devel
* Fri Jan 23 2015 jsegitz@novell.com
- Major cleanup of the spec file
* Fri Jan 23 2015 jsegitz@novell.com
- removed suse_minimal_cc.patch and splitted them into
  * suse_modifications_dbus.patch
  * suse_modifications_policykit.patch
  * suse_modifications_postfix.patch
  * suse_modifications_rtkit.patch
  * suse_modifications_unconfined.patch
  * suse_modifications_systemd.patch
  * suse_modifications_unconfineduser.patch
  * suse_modifications_selinuxutil.patch
  * suse_modifications_logging.patch
  * suse_modifications_getty.patch
  * suse_modifications_authlogin.patch
  * suse_modifications_xserver.patch
  * suse_modifications_ssh.patch
  * suse_modifications_usermanage.patch
- Added suse_modifications_virt.patch to enable svirt on s390x
* Sat Nov  8 2014 ledest@gmail.com
- fix bashism in post script
* Thu Sep 18 2014 jsegitz@suse.com
  Redid changes done by vcizek@suse.com in SLE12 package
- disable build of MLS policy
- removed outdated description files
  * Alan_Rouse-openSUSE_with_SELinux.txt
  * Alan_Rouse-Policy_Development_Process.txt
* Mon Sep  8 2014 jsegitz@suse.com
- removed remove_duplicate_filetrans_pattern_rules.patch
* Fri Sep  5 2014 jsegitz@suse.com
- Updated policy to include everything up until 20140730 (refpolicy and
  fedora rawhide improvements). Rebased all patches that are still
  necessary
- Removed permissivedomains.pp. Doesn't work with the new policy
- modified spec file so that all modifications for distro=redhat and
  distro=suse will be used.
- added selinux-policy-rpmlintrc to suppress some warnings that aren't
  valid for this package
- added suse_minimal_cc.patch to create a suse specific module to prevent
  errors while using the minimum policy. Will rework them in the proper
  places once the minimum policy is reworked to really only confine a
  minimal set of domains.
* Tue Sep  2 2014 vcizek@suse.com
- removed source files which were not used
  * modules-minimum.conf, modules-mls.conf, modules-targeted.conf,
    permissivedomains.fc, permissivedomains.if, permissivedomains.te,
    seusers, seusers-mls, seusers-targeted, users_extra-mls,
    users_extra-targeted
* Mon Jun  2 2014 vcizek@suse.com
- remove duplicate filetrans_pattern rules
  * fixes build with libsepol-2.3
  * added remove_duplicate_filetrans_pattern_rules.patch
* Mon Dec  9 2013 vcizek@suse.com
- enable build of mls and targeted policies
- fixes to the minimum policy:
- label /var/run/rsyslog correctly
  * label_var_run_rsyslog.patch
- allow systemd-tmpfiles to create devices
  * systemd-tmpfiles.patch
- add rules for sysconfig
  * correctly label /dev/.sysconfig/network
  * added sysconfig_network_scripts.patch
- run restorecon and fixfiles only if if selinux is enabled
- fix console login
  * allow-local_login_t-read-shadow.patch
- allow rsyslog to write to xconsole
  * xconsole.patch
- useradd needs to call selinux_check_access (via pam_rootok)
  * useradd-netlink_selinux_socket.patch
* Mon Aug 12 2013 ro@suse.de
- fix build on factory: newer rpm does not allow to mark
  non-directories as dir anymore (like symlinks in this case)
* Thu Jul 11 2013 coolo@suse.com
- install COPYING
* Fri Mar 22 2013 vcizek@suse.com
- switch to Fedora as upstream
- added patches:
  * policy-rawhide-base.patch
  * policy-rawhide-contrib.patch
  * type_transition_file_class.patch
  * type_transition_contrib.patch
  * label_sysconfig.selinux-policy.patch
* Tue Dec 11 2012 vcizek@suse.com
- bump up policy version to 27, due to recent libsepol update
- dropped currently unused policy-rawhide.patch
- fix installing of file_contexts (this enables restorecond to run properly)
- Recommends: audit and setools
* Mon Dec 10 2012 meissner@suse.com
- mark included files in source
* Mon Oct 22 2012 vcizek@suse.com
- update to 2.20120725
- added selinux-policy-run_sepolgen_during_build.patch
- renamed patch with SUSE-specific policy to selinux-policy-SUSE.patch
- dropped policygentool and OLPC stuff
* Wed May  9 2012 coolo@suse.com
- patch license to be in spdx.org format
* Fri May 21 2010 prusnak@suse.cz
- use policy created by Alan Rouse
* Sun Apr 11 2010 justinmattock@gmail.com
- Adjust selinux-policy.spec so that the policy
  source tree is put in /usr/share/doc/packages/selinux-*
  so users can build the policy [bnc#582404]
* Wed Apr  7 2010 thomas@novell.com
- fixed fileperms of /etc/selinux/config to be 644 to allow
  libselinux to read from it (bnc#582399)
  this is also the default file mode in fedora 12
* Fri Jun 26 2009 thomas@novell.com
- added config file for /etc/selinux/
* Wed Jan 14 2009 prusnak@suse.cz
- updated to version 2008.12.10
  * Fix consistency of audioentropy and iscsi module naming.
  * Debian file context fix for xen from Russell Coker.
  * Xserver MLS fix from Eamon Walsh.
  * Add omapi port for dhcpcd.
  * Deprecate per-role templates and rolemap support.
  * Implement user-based access control for use as role separations.
  * Move shared library calls from individual modules to the domain module.
  * Enable open permission checks policy capability.
  * Remove hierarchy from portage module as it is not a good example of hieararchy.
  * Remove enableaudit target from modular build as semodule -DB supplants it.
  * Added modules:
  - milter (Paul Howarth)
* Thu Oct 16 2008 prusnak@suse.cz
- updated to version 2008.10.14
  * Debian update for NetworkManager/wpa_supplicant from Martin Orr.
  * Logrotate and Bind updates from Vaclav Ovsik.
  * Init script file and domain support.
  * Glibc 2.7 fix from Vaclav Ovsik.
  * Samba/winbind update from Mike Edenfield.
  * Policy size optimization with a non-security file attribute from James Carter.
  * Database labeled networking update from KaiGai Kohei.
  * Several misc changes from the Fedora policy, cherry picked by David Hardeman.
  * Large whitespace fix from Dominick Grift.
  * Pam_mount fix for local login from Stefan Schulze Frielinghaus.
  * Issuing commands to upstart is over a datagram socket, not the initctl named pipe.
  * Updated init_telinit() to match.
  * Added modules:
  - cyphesis (Dan Walsh)
  - memcached (Dan Walsh)
  - oident (Dominick Grift)
  - w3c (Dan Walsh)
* Tue Jul 22 2008 prusnak@suse.cz
- initial version 2008.07.02 from tresys
